'use client'
var __require = /* @__PURE__ */ ((x) => typeof require !== "undefined" ? require : typeof Proxy !== "undefined" ? new Proxy(x, {
  get: (a, b) => (typeof require !== "undefined" ? require : a)[b]
}) : x)(function(x) {
  if (typeof require !== "undefined") return require.apply(this, arguments);
  throw Error('Dynamic require of "' + x + '" is not supported');
});

// src/common/ComponentManager.ts
import { useMemo } from "react";

// src/common/deepMerge.ts
import deepmerge from "deepmerge";
function isPlainObject(item) {
  return item !== null && typeof item === "object" && !Array.isArray(item) && // eslint-disable-next-line @typescript-eslint/ban-ts-comment
  // @ts-ignore
  // eslint-disable-next-line @typescript-eslint/no-unsafe-member-access
  !(typeof item?.type === "function") && !(item instanceof Date) && !(item instanceof RegExp) && !(item instanceof Map) && !(item instanceof Set);
}
function safeDeepMerge(target, source) {
  return deepmerge(target, source, {
    isMergeableObject: isPlainObject
  });
}

// src/common/ComponentManager.ts
var defaultProps = {};
var isDeepMergeEnabled = false;
var ComponentManager = {
  /**
   * Set & customize the default props conditionally
   * @param props named object mapping functions for each component
   */
  setDefaultProps(props) {
    defaultProps = {
      ...defaultProps,
      ...props
    };
  },
  enableDeepMerge(nextState) {
    isDeepMergeEnabled = !!nextState;
  }
};
var useMergedProps = (name, props, theme) => {
  return useMemo(() => {
    const initialProps = defaultProps?.[name]?.(props, theme);
    if (isDeepMergeEnabled) {
      return safeDeepMerge(initialProps, props);
    }
    return {
      ...initialProps,
      ...props
    };
  }, [name, props, theme]);
};

// src/common/useDeviceInfo.ts
import { useMemo as useMemo2 } from "react";
import { useWindowDimensions } from "react-native";
var useDeviceInfo = () => {
  const { width, height } = useWindowDimensions();
  const isLandscape = useMemo2(() => {
    return width > height;
  }, [height, width]);
  return {
    isPortrait: !isLandscape,
    isLandscape,
    width,
    height
  };
};

// src/context/BlossomThemeProvider.tsx
import React, { createContext, useContext, useMemo as useMemo3 } from "react";

// src/components/text/typography.ts
var typographyStyle = {
  h1: {
    fontSize: 36,
    fontWeight: "700"
  },
  h2: {
    fontSize: 32,
    fontWeight: "700"
  },
  h3: {
    fontSize: 28,
    fontWeight: "700"
  },
  h4: {
    fontSize: 24,
    fontWeight: "600"
  },
  h5: {
    fontSize: 20,
    fontWeight: "600"
  },
  h6: {
    fontSize: 18,
    fontWeight: "600"
  },
  // Body & other texts
  s1: {
    fontSize: 17,
    fontWeight: "600"
  },
  s2: {
    fontSize: 17,
    fontWeight: "400"
  },
  // Would be used for button
  b1: {
    fontSize: 16,
    fontWeight: "600"
  },
  b2: {
    fontSize: 16,
    fontWeight: "400"
  },
  b3: {
    fontSize: 15,
    fontWeight: "400"
  },
  l1: {
    fontSize: 14,
    fontWeight: "600"
  },
  l2: {
    fontSize: 14,
    fontWeight: "400"
  },
  c1: {
    fontSize: 13,
    fontWeight: "400"
  },
  c2: {
    fontSize: 12,
    fontWeight: "400"
  }
};

// src/context/defaultLightTheme.json
var defaultLightTheme_default = {
  primary100: "#e4ebfd",
  primary200: "#b5c8fa",
  primary300: "#8dadf8",
  primary400: "#548df6",
  primary500: "#1a7af5",
  primary600: "#1974e8",
  primary700: "#1666cd",
  primary800: "#1256ad",
  primary900: "#0c376e",
  primaryTransparent100: "#1a7af51a",
  primaryTransparent200: "#1a7af533",
  primaryTransparent300: "#1a7af54d",
  primaryTransparent400: "#1a7af566",
  primaryTransparent500: "#1a7af580",
  accent100: "#ebe5f8",
  accent200: "#c8b7ed",
  accent300: "#ad91e6",
  accent400: "#8e5cde",
  accent500: "#7b2eda",
  accent600: "#752ccf",
  accent700: "#6726b6",
  accent800: "#57219a",
  accent900: "#371561",
  accentTransparent100: "#7b2eda1a",
  accentTransparent200: "#7b2eda33",
  accentTransparent300: "#7b2eda4d",
  accentTransparent400: "#7b2eda66",
  accentTransparent500: "#7b2eda80",
  success100: "#e5f3e5",
  success200: "#b6e0b8",
  success300: "#8fd292",
  success400: "#57c35e",
  success500: "#22bb33",
  success600: "#20b130",
  success700: "#1c9c2b",
  success800: "#188424",
  success900: "#0f5417",
  successTransparent100: "#22bb331a",
  successTransparent200: "#22bb3333",
  successTransparent300: "#22bb334d",
  successTransparent400: "#22bb3366",
  successTransparent500: "#22bb3380",
  info100: "#e5effa",
  info200: "#b7d4f2",
  info300: "#91c0ed",
  info400: "#5ba9e8",
  info500: "#2d9de5",
  info600: "#2b95d9",
  info700: "#2683c0",
  info800: "#206fa2",
  info900: "#144666",
  infoTransparent100: "#2d9de51a",
  infoTransparent200: "#2d9de533",
  infoTransparent300: "#2d9de54d",
  infoTransparent400: "#2d9de566",
  infoTransparent500: "#2d9de580",
  warning100: "#fef9e7",
  warning200: "#fcf0be",
  warning300: "#fbea9c",
  warning400: "#fae471",
  warning500: "#f9e154",
  warning600: "#ecd550",
  warning700: "#d0bc46",
  warning800: "#b09f3b",
  warning900: "#6f6526",
  warningTransparent100: "#f9e1541a",
  warningTransparent200: "#f9e15433",
  warningTransparent300: "#f9e1544d",
  warningTransparent400: "#f9e15466",
  warningTransparent500: "#f9e15480",
  error100: "#ffe5e5",
  error200: "#ffb8b8",
  error300: "#ff9292",
  error400: "#ff5e5e",
  error500: "#ff3333",
  error600: "#f23030",
  error700: "#d52b2b",
  error800: "#b42424",
  error900: "#721717",
  errorTransparent100: "#ff33331a",
  errorTransparent200: "#ff333333",
  errorTransparent300: "#ff33334d",
  errorTransparent400: "#ff333366",
  errorTransparent500: "#ff333380",
  background100: "#ffffff",
  background200: "#dfdfdf",
  background300: "#bfbfc0",
  background400: "#a1a1a2",
  background500: "#838385",
  background600: "#676769",
  background700: "#4c4c4e",
  background800: "#333334",
  background900: "#1b1b1d",
  backgroundTransparent100: "#dfdfdf1a",
  backgroundTransparent200: "#dfdfdf33",
  backgroundTransparent300: "#dfdfdf4d",
  backgroundTransparent400: "#dfdfdf66",
  backgroundTransparent500: "#dfdfdf80",
  text100: "#000000",
  text200: "#212121",
  text300: "#3b3b3b",
  text400: "#585858",
  text500: "#777777",
  text600: "#979797",
  text700: "#b9b9b9",
  text800: "#dbdbdb",
  text900: "#ffffff",
  bgLight100: "#ffffff",
  bgLight200: "#eeeeee",
  bgLight300: "#dedede",
  bgLight400: "#cecece",
  bgLight500: "#bdbdbd",
  bgLight600: "#aeaeae",
  bgLight700: "#9e9e9e",
  bgLight800: "#8f8f8f",
  bgLight900: "#808080",
  bgDark100: "#808080",
  bgDark200: "#6f6f6f",
  bgDark300: "#5f5f5f",
  bgDark400: "#4f4f4f",
  bgDark500: "#3f3f3f",
  bgDark600: "#303030",
  bgDark700: "#222222",
  bgDark800: "#151515",
  bgDark900: "#000000"
};

// src/context/defaultDarkTheme.json
var defaultDarkTheme_default = {
  primary100: "#e4ebfd",
  primary200: "#b5c8fa",
  primary300: "#8dadf8",
  primary400: "#548df6",
  primary500: "#1a7af5",
  primary600: "#1974e8",
  primary700: "#1666cd",
  primary800: "#1256ad",
  primary900: "#0c376e",
  primaryTransparent100: "#1a7af51a",
  primaryTransparent200: "#1a7af533",
  primaryTransparent300: "#1a7af54d",
  primaryTransparent400: "#1a7af566",
  primaryTransparent500: "#1a7af580",
  accent100: "#ebe5f8",
  accent200: "#c8b7ed",
  accent300: "#ad91e6",
  accent400: "#8e5cde",
  accent500: "#7b2eda",
  accent600: "#752ccf",
  accent700: "#6726b6",
  accent800: "#57219a",
  accent900: "#371561",
  accentTransparent100: "#7b2eda1a",
  accentTransparent200: "#7b2eda33",
  accentTransparent300: "#7b2eda4d",
  accentTransparent400: "#7b2eda66",
  accentTransparent500: "#7b2eda80",
  success100: "#e5f3e5",
  success200: "#b6e0b8",
  success300: "#8fd292",
  success400: "#57c35e",
  success500: "#22bb33",
  success600: "#20b130",
  success700: "#1c9c2b",
  success800: "#188424",
  success900: "#0f5417",
  successTransparent100: "#22bb331a",
  successTransparent200: "#22bb3333",
  successTransparent300: "#22bb334d",
  successTransparent400: "#22bb3366",
  successTransparent500: "#22bb3380",
  info100: "#e5effa",
  info200: "#b7d4f2",
  info300: "#91c0ed",
  info400: "#5ba9e8",
  info500: "#2d9de5",
  info600: "#2b95d9",
  info700: "#2683c0",
  info800: "#206fa2",
  info900: "#144666",
  infoTransparent100: "#2d9de51a",
  infoTransparent200: "#2d9de533",
  infoTransparent300: "#2d9de54d",
  infoTransparent400: "#2d9de566",
  infoTransparent500: "#2d9de580",
  warning100: "#fef9e7",
  warning200: "#fcf0be",
  warning300: "#fbea9c",
  warning400: "#fae471",
  warning500: "#f9e154",
  warning600: "#ecd550",
  warning700: "#d0bc46",
  warning800: "#b09f3b",
  warning900: "#6f6526",
  warningTransparent100: "#f9e1541a",
  warningTransparent200: "#f9e15433",
  warningTransparent300: "#f9e1544d",
  warningTransparent400: "#f9e15466",
  warningTransparent500: "#f9e15480",
  error100: "#ffe5e5",
  error200: "#ffb8b8",
  error300: "#ff9292",
  error400: "#ff5e5e",
  error500: "#ff3333",
  error600: "#f23030",
  error700: "#d52b2b",
  error800: "#b42424",
  error900: "#721717",
  errorTransparent100: "#ff33331a",
  errorTransparent200: "#ff333333",
  errorTransparent300: "#ff33334d",
  errorTransparent400: "#ff333366",
  errorTransparent500: "#ff333380",
  background100: "#1b1b1d",
  background200: "#333334",
  background300: "#4c4c4e",
  background400: "#676769",
  background500: "#838385",
  background600: "#a1a1a2",
  background700: "#bfbfc0",
  background800: "#dfdfdf",
  background900: "#ffffff",
  backgroundTransparent100: "#3333341a",
  backgroundTransparent200: "#33333433",
  backgroundTransparent300: "#3333344d",
  backgroundTransparent400: "#33333466",
  backgroundTransparent500: "#33333480",
  text100: "#ffffff",
  text200: "#dbdbdb",
  text300: "#b9b9b9",
  text400: "#979797",
  text500: "#777777",
  text600: "#585858",
  text700: "#3b3b3b",
  text800: "#212121",
  text900: "#000000",
  bgLight100: "#ffffff",
  bgLight200: "#eeeeee",
  bgLight300: "#dedede",
  bgLight400: "#cecece",
  bgLight500: "#bdbdbd",
  bgLight600: "#aeaeae",
  bgLight700: "#9e9e9e",
  bgLight800: "#8f8f8f",
  bgLight900: "#808080",
  bgDark100: "#808080",
  bgDark200: "#6f6f6f",
  bgDark300: "#5f5f5f",
  bgDark400: "#4f4f4f",
  bgDark500: "#3f3f3f",
  bgDark600: "#303030",
  bgDark700: "#222222",
  bgDark800: "#151515",
  bgDark900: "#000000"
};

// src/context/BlossomThemeProvider.tsx
var defaultValue = {
  colors: defaultLightTheme_default,
  isDark: false,
  options: {
    borderRadius: 12,
    typography: typographyStyle
  }
};
var BlossomThemeContext = createContext(defaultValue);
var BlossomThemeProvider = ({
  theme = defaultLightTheme_default,
  isDark,
  options,
  children
}) => {
  const values = useMemo3(
    () => ({
      colors: safeDeepMerge(
        isDark ? defaultDarkTheme_default : defaultLightTheme_default,
        theme
      ),
      isDark,
      options: safeDeepMerge(
        defaultValue.options || {},
        options || {}
      )
    }),
    [theme, isDark, options]
  );
  return /* @__PURE__ */ React.createElement(BlossomThemeContext.Provider, { value: values }, children);
};
var useBlossomTheme = () => useContext(BlossomThemeContext);

// src/components/text/Text.tsx
import React2, { forwardRef } from "react";
import { Text as RNText } from "react-native";

// src/components/utils/index.ts
import chroma2 from "chroma-js";

// src/components/utils/colorUtils.ts
import chroma from "chroma-js";
var getAlphaColor = (inputColor, alpha = 0.5) => {
  if (!inputColor) return "";
  return chroma(inputColor).alpha(alpha).hex();
};
var getDarkenColor = (inputColor, darken = 0.5) => {
  if (!inputColor) return "";
  return chroma(inputColor).darken(darken).hex();
};

// src/components/utils/index.ts
var getStatusColorName = (status, isDark, colorVariant = "500") => {
  if (!status) return "background900";
  const color = `${status}${colorVariant}`;
  return color;
};
var getTransparentStatusColorName = (status, colorVariant = "500") => {
  if (!status) return "background900";
  const color = `${status}Transparent${colorVariant}`;
  return color;
};
var getBorderColorName = (status, isDark, colorVariant = "500") => {
  if (!status) return "background300";
  const color = `${status}${colorVariant}`;
  return color;
};
var getTextColorName = (color, isDark, isDisabled, mode = "filled") => {
  if (!color) return "text100";
  if (isDisabled) {
    const modeColorMap = {
      filled: "text500",
      tinted: "text500",
      outlined: "text600",
      plain: "text600"
    };
    return modeColorMap[mode];
  }
  const lum = chroma2(color).luminance();
  if (isDark) {
    return lum < 0.4 ? "text100" : "text900";
  }
  return lum < 0.4 ? "text900" : "text100";
};

// src/components/text/Text.tsx
var Text = (props, ref) => {
  const { colors, isDark, options } = useBlossomTheme();
  const { typography = "b2", ...rest } = useMergedProps("Text", props, {
    colors,
    isDark
  });
  return /* @__PURE__ */ React2.createElement(
    RNText,
    {
      ref,
      ...rest,
      style: [
        options?.typography?.[typography],
        { color: colors[getStatusColorName(rest?.status, isDark)] },
        rest?.style
      ]
    }
  );
};
var Text_default = forwardRef(Text);

// src/components/text/Link.tsx
import React4, { useCallback } from "react";
import { Linking, StyleSheet as StyleSheet2, TouchableOpacity } from "react-native";

// src/components/view/View.tsx
import React3, { forwardRef as forwardRef2 } from "react";
import { View as RNView, StyleSheet } from "react-native";
var View = (props, ref) => {
  const { colors, isDark } = useBlossomTheme();
  const { row, ...rest } = useMergedProps("View", props, { colors, isDark });
  return /* @__PURE__ */ React3.createElement(
    RNView,
    {
      ref,
      ...rest,
      style: [
        { backgroundColor: colors.background100 },
        row && styles.row,
        rest.style
      ]
    }
  );
};
var View_default = forwardRef2(View);
var styles = StyleSheet.create({
  row: {
    flexDirection: "row"
  }
});

// src/components/text/Link.tsx
var SPACE = " ";
var Link = (props) => {
  const { colors, isDark } = useBlossomTheme();
  const {
    leftText,
    rightText,
    title = "",
    style,
    href = "",
    onLinkOpenError,
    ...rest
  } = useMergedProps("Link", props, {
    colors,
    isDark
  });
  const onTextPress = useCallback(async () => {
    try {
      const canOpen = await Linking.canOpenURL(href);
      if (canOpen) await Linking.openURL(href);
    } catch (error) {
      onLinkOpenError?.(error);
    }
  }, [href, onLinkOpenError]);
  return /* @__PURE__ */ React4.createElement(View_default, { row: true }, typeof leftText === "string" ? /* @__PURE__ */ React4.createElement(Text_default, null, leftText, SPACE) : leftText, /* @__PURE__ */ React4.createElement(
    TouchableOpacity,
    {
      accessibilityRole: "link",
      activeOpacity: 0.5,
      onPress: onTextPress
    },
    /* @__PURE__ */ React4.createElement(
      Text_default,
      {
        ...rest,
        style: [
          {
            color: colors.info500
          },
          styles2.link,
          style
        ]
      },
      title
    )
  ), typeof rightText === "string" ? /* @__PURE__ */ React4.createElement(Text_default, null, SPACE, rightText) : rightText);
};
var Link_default = Link;
var styles2 = StyleSheet2.create({
  link: {
    textDecorationLine: "underline"
  }
});

// src/components/text/ExpandableText.tsx
import React5, { useState, useEffect, useCallback as useCallback2 } from "react";
import {
  TouchableOpacity as TouchableOpacity2,
  StyleSheet as StyleSheet3
} from "react-native";
function ExpandableText(props) {
  const { colors, isDark } = useBlossomTheme();
  const { numberOfLines = 3, ...rest } = useMergedProps("ExpandableText", props, {
    colors,
    isDark
  });
  const [isExpanded, setIsExpanded] = useState(false);
  const [isTextClipped, setIsTextClipped] = useState(false);
  const [hasLayoutCompleted, setHasLayoutCompleted] = useState(false);
  const toggleExpanded = () => {
    setIsExpanded((prev) => !prev);
  };
  const handleTextLayout = useCallback2(
    (e) => {
      const { lines } = e.nativeEvent;
      const lastLineWidth = lines[lines.length - 1].width;
      const maxWidthAvailable = Math.min(...lines.map((line) => line.width));
      const isClipped = lines.length > numberOfLines || lines.length === numberOfLines && lastLineWidth > maxWidthAvailable;
      setIsTextClipped(isClipped);
      setHasLayoutCompleted(true);
    },
    [numberOfLines]
  );
  useEffect(() => {
    setHasLayoutCompleted(false);
  }, [rest?.children]);
  return /* @__PURE__ */ React5.createElement(View_default, null, /* @__PURE__ */ React5.createElement(
    Text_default,
    {
      onTextLayout: !hasLayoutCompleted ? handleTextLayout : void 0,
      numberOfLines: isExpanded ? void 0 : numberOfLines,
      ellipsizeMode: "tail",
      ...rest
    }
  ), isTextClipped && /* @__PURE__ */ React5.createElement(
    TouchableOpacity2,
    {
      accessibilityRole: "button",
      activeOpacity: 0.4,
      style: styles3.readMore,
      onPress: toggleExpanded
    },
    /* @__PURE__ */ React5.createElement(Text_default, { status: "primary", typography: "b3" }, isExpanded ? "Read Less" : "Read More")
  ));
}
var ExpandableText_default = ExpandableText;
var styles3 = StyleSheet3.create({
  readMore: {
    marginTop: 4
  }
});

// src/components/loader/ActivityIndicator.tsx
import React13, { useCallback as useCallback5 } from "react";
import {
  ActivityIndicator as RNActivityIndicator,
  Platform as Platform2,
  StyleSheet as StyleSheet9
} from "react-native";

// src/components/view/Card.tsx
import React6 from "react";
import { Platform, StyleSheet as StyleSheet4 } from "react-native";
var CardView = (props) => {
  const { colors, options, isDark } = useBlossomTheme();
  const { style, ...rest } = useMergedProps("Card", props, { colors, isDark });
  return /* @__PURE__ */ React6.createElement(
    View_default,
    {
      style: [
        styles4.shadow,
        styles4.border,
        {
          borderRadius: options?.borderRadius,
          shadowColor: colors.background300,
          borderColor: colors.background400
        },
        Platform.select({
          web: {
            boxShadow: `1px 1px 1px 1px ${colors.background300}`
          }
        }),
        style
      ],
      ...rest
    }
  );
};
var CardCover = (props) => {
  const { colors, isDark, options } = useBlossomTheme();
  const { style, ...rest } = useMergedProps("Card.Cover", props, {
    colors,
    isDark
  });
  return /* @__PURE__ */ React6.createElement(
    View_default,
    {
      style: [
        styles4.cover,
        {
          borderTopLeftRadius: options?.borderRadius,
          borderTopRightRadius: options?.borderRadius
        },
        style
      ],
      ...rest
    }
  );
};
var CardContent = (props) => {
  const { colors, isDark } = useBlossomTheme();
  const { style, ...rest } = useMergedProps("Card.Content", props, {
    colors,
    isDark
  });
  return /* @__PURE__ */ React6.createElement(View_default, { style: [styles4.content, style], ...rest });
};
var Card = Object.assign(CardView, {
  Content: CardContent,
  Cover: CardCover
});
var Card_default = Card;
var styles4 = StyleSheet4.create({
  border: {
    borderWidth: 0.2
  },
  shadow: {
    ...Platform.select({
      android: {
        elevation: 2
      },
      ios: {
        borderWidth: 1,
        borderColor: "red",
        shadowOpacity: 1,
        shadowRadius: 1,
        shadowOffset: {
          width: 0.5,
          height: 0.5
        }
      }
    })
  },
  content: {
    padding: 10,
    backgroundColor: "transparent"
  },
  cover: {
    overflow: "hidden",
    marginBottom: 4
  }
});

// src/components/view/Spacer.tsx
import React7 from "react";
import { StyleSheet as StyleSheet5 } from "react-native";
var Spacer = (props) => {
  const { colors, isDark } = useBlossomTheme();
  const {
    width,
    height = 10,
    ...rest
  } = useMergedProps("Spacer", props, { colors, isDark });
  return /* @__PURE__ */ React7.createElement(View_default, { ...rest, style: [styles5.transparent, { width, height }, rest.style] });
};
var Spacer_default = Spacer;
var styles5 = StyleSheet5.create({
  transparent: {
    backgroundColor: "transparent"
  }
});

// src/components/view/Divider.tsx
import React8, { useCallback as useCallback3, useMemo as useMemo4 } from "react";
import { View as RNView2, StyleSheet as StyleSheet6 } from "react-native";
var Divider = (props) => {
  const { colors, isDark } = useBlossomTheme();
  const {
    width,
    height = 1,
    color = colors.background600,
    label,
    labelPosition = "center",
    ...rest
  } = useMergedProps("Divider", props, { colors, isDark });
  const lineStyle = useMemo4(
    () => StyleSheet6.flatten([
      {
        width,
        height,
        backgroundColor: color
      },
      styles6.line,
      rest?.style
    ]),
    [width, height, color, rest?.style]
  );
  const renderLine = useCallback3(
    () => /* @__PURE__ */ React8.createElement(RNView2, { ...rest, style: lineStyle }),
    [lineStyle, rest]
  );
  const renderLabel = useCallback3(
    () => label ? /* @__PURE__ */ React8.createElement(Text_default, { style: [styles6[labelPosition], { color }] }, label) : rest?.children,
    [color, label, labelPosition, rest?.children]
  );
  if (label || rest?.children)
    return /* @__PURE__ */ React8.createElement(View_default, { row: true, style: styles6.container }, labelPosition === "center" && renderLine(), labelPosition !== "right" && renderLabel(), labelPosition !== "right" && renderLine(), labelPosition === "right" && renderLine(), labelPosition === "right" && renderLabel());
  return /* @__PURE__ */ React8.createElement(
    RNView2,
    {
      ...rest,
      style: [
        {
          width,
          height,
          backgroundColor: color
        },
        rest?.style
      ]
    }
  );
};
var Divider_default = Divider;
var styles6 = StyleSheet6.create({
  container: {
    alignItems: "center"
  },
  line: {
    flex: 1
  },
  left: {
    marginEnd: 8
  },
  center: {
    marginHorizontal: 8
  },
  right: {
    marginStart: 8
  }
});

// src/components/view/Accordion.tsx
import React10, { useEffect as useEffect2, useState as useState2, useRef, useCallback as useCallback4 } from "react";
import {
  Pressable,
  StyleSheet as StyleSheet7,
  Animated,
  UIManager,
  View as RNView3
} from "react-native";

// src/components/icon/Icon.tsx
import React9 from "react";
import { TouchableOpacity as TouchableOpacity3 } from "react-native";
var Icon = (props) => {
  const { colors, isDark } = useBlossomTheme();
  const {
    status,
    size = 24,
    family = "Ionicons",
    ...rest
  } = useMergedProps("Icon", props, { colors, isDark });
  const IconComponent = getIconFamily(family);
  return rest?.onPress ? /* @__PURE__ */ React9.createElement(
    TouchableOpacity3,
    {
      accessibilityRole: "button",
      activeOpacity: 0.5,
      disabled: rest?.disabled,
      onPress: rest?.onPress
    },
    /* @__PURE__ */ React9.createElement(
      IconComponent,
      {
        color: colors[getStatusColorName(status, isDark)],
        size,
        ...rest,
        onPress: void 0
      }
    )
  ) : (
    // eslint-disable-next-line @typescript-eslint/ban-ts-comment
    // @ts-expect-error
    /* @__PURE__ */ React9.createElement(
      IconComponent,
      {
        color: colors[getStatusColorName(status, isDark)],
        size,
        ...rest
      }
    )
  );
};
var Icon_default = Icon;
var getIconFamily = (family = "Ionicons") => {
  const familyMap = {
    AntDesign: __require("react-native-vector-icons/AntDesign").default,
    Entypo: __require("react-native-vector-icons/Entypo").default,
    EvilIcons: __require("react-native-vector-icons/EvilIcons").default,
    Feather: __require("react-native-vector-icons/Feather").default,
    FontAwesome: __require("react-native-vector-icons/FontAwesome").default,
    FontAwesome5: __require("react-native-vector-icons/FontAwesome5").default,
    Fontisto: __require("react-native-vector-icons/Fontisto").default,
    Foundation: __require("react-native-vector-icons/Foundation").default,
    Ionicons: __require("react-native-vector-icons/Ionicons").default,
    MaterialCommunityIcons: __require("react-native-vector-icons/MaterialCommunityIcons").default,
    MaterialIcons: __require("react-native-vector-icons/MaterialIcons").default,
    Octicons: __require("react-native-vector-icons/Octicons").default,
    SimpleLineIcons: __require("react-native-vector-icons/SimpleLineIcons").default,
    Zocial: __require("react-native-vector-icons/Zocial").default
  };
  return familyMap[family];
};

// src/components/view/Accordion.tsx
if (UIManager.setLayoutAnimationEnabledExperimental) {
  UIManager.setLayoutAnimationEnabledExperimental(true);
}
var Accordion = (props) => {
  const { colors, isDark } = useBlossomTheme();
  const {
    isOpen,
    title,
    description,
    content,
    children,
    left,
    right,
    chevron,
    containerStyle,
    headerStyle,
    onPress,
    transitionDuration = 300
  } = useMergedProps("Accordion", props, { colors, isDark });
  const [isExpanded, setIsExpanded] = useState2(false);
  const [contentHeight, setContentHeight] = useState2(0);
  const animatedHeight = useRef(new Animated.Value(0)).current;
  const rotateAnimation = useRef(new Animated.Value(0)).current;
  useEffect2(() => {
    setIsExpanded(!!isOpen);
  }, [isOpen]);
  const toggleAccordion = useCallback4(() => {
    setIsExpanded((prev) => !prev);
    onPress?.();
    const toValue = isExpanded ? 0 : 1;
    Animated.timing(animatedHeight, {
      toValue: toValue * contentHeight,
      duration: transitionDuration,
      useNativeDriver: false
    }).start();
    if (chevron) return;
    Animated.timing(rotateAnimation, {
      toValue,
      duration: transitionDuration,
      useNativeDriver: true
    }).start();
  }, [
    chevron,
    isExpanded,
    onPress,
    animatedHeight,
    contentHeight,
    transitionDuration,
    rotateAnimation
  ]);
  const onLayout = useCallback4((event) => {
    const { height } = event.nativeEvent.layout;
    if (height > 0) {
      setContentHeight(height);
    }
  }, []);
  const chevronRotation = rotateAnimation.interpolate({
    inputRange: [0, 1],
    outputRange: ["0deg", "180deg"]
  });
  return /* @__PURE__ */ React10.createElement(View_default, { style: containerStyle }, /* @__PURE__ */ React10.createElement(
    Pressable,
    {
      accessibilityRole: "button",
      style: [styles7.titleRow, headerStyle],
      onPress: toggleAccordion
    },
    left,
    /* @__PURE__ */ React10.createElement(View_default, { style: [styles7.titleColumn, !left && styles7.titleLeft] }, typeof title === "string" ? /* @__PURE__ */ React10.createElement(Text_default, { typography: "b1" }, title) : title, typeof description === "string" ? /* @__PURE__ */ React10.createElement(Text_default, { typography: "l2", style: { color: colors.text400 } }, description) : description),
    right,
    chevron?.(isExpanded) || /* @__PURE__ */ React10.createElement(Animated.View, { style: { transform: [{ rotate: chevronRotation }] } }, /* @__PURE__ */ React10.createElement(
      Icon_default,
      {
        family: "Ionicons",
        name: "chevron-down",
        color: colors.text200
      }
    ))
  ), /* @__PURE__ */ React10.createElement(
    Animated.View,
    {
      style: [
        {
          height: animatedHeight
        },
        styles7.contentAnimatedView
      ]
    },
    /* @__PURE__ */ React10.createElement(RNView3, { style: styles7.contentView, onLayout }, /* @__PURE__ */ React10.createElement(Spacer_default, null), typeof content === "string" ? /* @__PURE__ */ React10.createElement(Text_default, null, content) : children)
  ));
};
var Accordion_default = Accordion;
var styles7 = StyleSheet7.create({
  contentView: {
    position: "absolute"
  },
  contentAnimatedView: {
    overflow: "hidden",
    backgroundColor: "transparent"
  },
  titleColumn: {
    flex: 1,
    marginHorizontal: 12
  },
  titleLeft: {
    marginStart: 0
  },
  titleRow: {
    flexDirection: "row",
    justifyContent: "space-between",
    alignItems: "center"
  },
  title: {
    flex: 1
  }
});

// src/components/view/ShimmerView.tsx
import React11, { useEffect as useEffect3, useMemo as useMemo5, useRef as useRef2 } from "react";
import { Animated as Animated2, Easing, StyleSheet as StyleSheet8, useWindowDimensions as useWindowDimensions2 } from "react-native";
var ShimmerView = (props) => {
  const { colors, isDark, options } = useBlossomTheme();
  const {
    width,
    height = 10,
    visible = true,
    animated = true,
    circular,
    duration = 1e3,
    mode = "fade",
    color = colors.background200,
    borderRadius = options?.borderRadius,
    ...rest
  } = useMergedProps("ShimmerView", props, { colors, isDark });
  const { width: deviceWidth } = useWindowDimensions2();
  const animation = useRef2(new Animated2.Value(mode === "fade" ? 1 : 0)).current;
  const fadeLoop = useMemo5(
    () => Animated2.loop(
      Animated2.sequence([
        Animated2.timing(animation, {
          toValue: 0,
          duration,
          easing: Easing.linear,
          useNativeDriver: true
        }),
        Animated2.timing(animation, {
          toValue: 1,
          duration,
          easing: Easing.linear,
          useNativeDriver: true
        })
      ])
    ),
    [animation, duration]
  );
  const waveLoop = useMemo5(
    () => Animated2.loop(
      Animated2.timing(animation, {
        toValue: 1,
        duration,
        useNativeDriver: true
      })
    ),
    [animation, duration]
  );
  useEffect3(() => {
    if (!visible) return;
    if (animated) {
      if (mode === "fade") {
        waveLoop.reset();
        fadeLoop.start();
      } else {
        fadeLoop.reset();
        waveLoop.start();
      }
    } else {
      mode === "fade" ? fadeLoop.reset() : waveLoop.reset();
    }
  }, [fadeLoop, animated, visible, mode, waveLoop]);
  if (!visible) {
    return /* @__PURE__ */ React11.createElement(View_default, { ...rest });
  }
  return /* @__PURE__ */ React11.createElement(
    Animated2.View,
    {
      ...rest,
      style: [
        styles8.container,
        {
          width,
          height,
          backgroundColor: color,
          borderRadius
        },
        circular && {
          width: height,
          height,
          borderRadius: parseInt(String(height), 10)
        },
        mode === "fade" && {
          opacity: animation.interpolate({
            inputRange: [0, 1],
            outputRange: [0.4, 1]
          }),
          backgroundColor: animation.interpolate({
            inputRange: [0, 1],
            outputRange: [colors.backgroundTransparent500, color]
          })
        },
        rest.style
      ]
    },
    visible ? mode === "wave" ? /* @__PURE__ */ React11.createElement(
      Animated2.View,
      {
        style: [
          styles8.pulseView,
          {
            width: deviceWidth * 0.1,
            backgroundColor: getAlphaColor(colors.background100, 0.6)
          },
          {
            transform: [
              {
                translateX: animation.interpolate({
                  inputRange: [0, 1],
                  outputRange: [-deviceWidth, deviceWidth]
                })
              }
            ]
          }
        ]
      }
    ) : null : rest.children
  );
};
var ShimmerView_default = ShimmerView;
var styles8 = StyleSheet8.create({
  container: {
    marginVertical: 8,
    overflow: "hidden"
  },
  pulseView: {
    minWidth: 20,
    height: "100%",
    opacity: 0.5,
    shadowColor: "#ffffff",
    shadowOffset: { width: 50, height: 0 },
    shadowOpacity: 1,
    shadowRadius: 20
  }
});

// src/components/text/SizedText.tsx
import React12 from "react";
var SizedText = (props) => {
  const { mode = "label", size = "medium", ...rest } = props;
  return /* @__PURE__ */ React12.createElement(Text_default, { typography: sizeMap[size][mode], ...rest });
};
var SizedText_default = SizedText;
var sizeMap = {
  small: {
    label: "c1",
    caption: "c2",
    body: "l2"
  },
  medium: {
    label: "l2",
    caption: "c1",
    body: "b2"
  },
  large: {
    label: "b3",
    caption: "l2",
    body: "s2"
  }
};

// src/components/loader/ActivityIndicator.tsx
var ActivityIndicator = (props) => {
  const { colors, isDark } = useBlossomTheme();
  const {
    visible = true,
    status = "primary",
    size = "medium",
    label,
    labelStyle,
    containerStyle,
    ...rest
  } = useMergedProps("Loader", props, { colors, isDark });
  const getScale = useCallback5(() => {
    if (Platform2.OS === "ios") {
      const scale = (typeof size === "number" ? size : sizeMap2[size]) / 20;
      return scale;
    }
    return 1;
  }, [size]);
  const getActivityIndicator = useCallback5(() => {
    return /* @__PURE__ */ React13.createElement(
      RNActivityIndicator,
      {
        color: colors[getStatusColorName(status, isDark)],
        ...rest,
        size: typeof size === "number" ? size : sizeMap2[size],
        style: [
          {
            transform: [{ scaleX: getScale() }, { scaleY: getScale() }]
          },
          rest.style
        ]
      }
    );
  }, [colors, getScale, isDark, rest, size, status]);
  return visible ? label ? /* @__PURE__ */ React13.createElement(View_default, { style: [styles9.container, containerStyle] }, getActivityIndicator(), label ? /* @__PURE__ */ React13.createElement(
    SizedText_default,
    {
      size: typeof size === "string" ? size : "medium",
      style: [styles9.label, labelStyle]
    },
    label
  ) : null) : getActivityIndicator() : null;
};
var ActivityIndicator_default = ActivityIndicator;
var styles9 = StyleSheet9.create({
  container: {
    alignSelf: "center"
  },
  label: {
    marginTop: 8
  }
});
var sizeMap2 = {
  small: 20,
  medium: 28,
  large: 36
};

// src/components/input/SearchInput.tsx
import React16, { forwardRef as forwardRef4, useCallback as useCallback6, useEffect as useEffect6, useState as useState6 } from "react";

// src/components/input/TextInput.tsx
import React14, { forwardRef as forwardRef3, useMemo as useMemo6, useState as useState3 } from "react";
import { Platform as Platform3, TextInput as RNTextInput, StyleSheet as StyleSheet10 } from "react-native";
var TextInput = (props, ref) => {
  const { colors, isDark, options } = useBlossomTheme();
  const {
    label,
    placeholder,
    placeholderComponent,
    caption,
    error,
    labelStyle,
    placeholderStyle,
    captionStyle,
    errorStyle,
    disabled,
    shouldMockDisableState,
    mode = "outlined",
    dense,
    left,
    right,
    containerStyle,
    inputStyle,
    textStyle,
    status,
    size = "medium",
    ...rest
  } = useMergedProps("TextInput", props, { colors, isDark });
  const [isFocused, setIsFocused] = useState3(false);
  const textInputSizeStyle = useMemo6(() => textInputSizeStylesMap, []);
  return /* @__PURE__ */ React14.createElement(View_default, { style: [styles10.containerStyle, containerStyle] }, label ? /* @__PURE__ */ React14.createElement(
    SizedText_default,
    {
      size,
      status: error ? "error" : void 0,
      style: [
        !error && {
          color: disabled ? colors.text400 : colors.text100
        },
        labelStyle
      ]
    },
    label
  ) : null, /* @__PURE__ */ React14.createElement(
    View_default,
    {
      style: [
        styles10.innerContainer,
        mode === "outlined" ? [
          styles10.outlined,
          textInputSizeStyle[size].outlined,
          {
            borderRadius: options?.borderRadius
          }
        ] : styles10.flat,
        {
          backgroundColor: dense ? colors.backgroundTransparent300 : void 0,
          borderColor: disabled ? colors.background500 : colors[getBorderColorName(
            error ? "error" : status || (isFocused ? "primary" : void 0),
            isDark
          )]
        },
        inputStyle
      ]
    },
    left,
    placeholderComponent,
    /* @__PURE__ */ React14.createElement(
      RNTextInput,
      {
        ref,
        placeholderTextColor: colors.text400,
        ...rest,
        placeholder: placeholderComponent ? "" : placeholder,
        editable: !(disabled || shouldMockDisableState),
        focusable: !(disabled || shouldMockDisableState),
        style: [
          styles10.inputText,
          textInputSizeStyle[size].inputText,
          {
            color: disabled ? colors.text500 : colors.text100
          },
          left ? styles10.leftMargin : {},
          textStyle,
          Platform3.OS === "web" && {
            // Note: this style won't work in the stylesheet
            // eslint-disable-next-line @typescript-eslint/ban-ts-comment
            // @ts-ignore
            outline: "none"
          }
        ],
        onFocus: (e) => {
          setIsFocused(true);
          rest?.onFocus?.(e);
        },
        onBlur: (e) => {
          setIsFocused(false);
          rest?.onBlur?.(e);
        }
      }
    ),
    right
  ), caption ? /* @__PURE__ */ React14.createElement(SizedText_default, { size, mode: "caption", style: [captionStyle] }, caption) : null, error ? /* @__PURE__ */ React14.createElement(SizedText_default, { size, status: "error", style: [errorStyle] }, error) : null);
};
var TextInput_default = forwardRef3(TextInput);
var styles10 = StyleSheet10.create({
  containerStyle: {
    minWidth: 100
  },
  innerContainer: {
    marginVertical: 6,
    flexDirection: "row",
    alignItems: "center",
    justifyContent: "space-between",
    overflow: "hidden"
  },
  leftMargin: {
    marginHorizontal: 6
  },
  inputText: {
    flex: 1,
    marginHorizontal: 2
  },
  outlined: {
    borderWidth: 1
  },
  flat: {
    paddingTop: 4,
    paddingBottom: 6,
    borderBottomWidth: 1
  }
});
var textInputSizeStylesMap = {
  small: {
    outlined: {
      padding: 6
    },
    inputText: {
      fontSize: 14
    }
  },
  medium: {
    outlined: {
      padding: 9
    },
    inputText: {
      fontSize: 16
    }
  },
  large: {
    outlined: {
      padding: 12
    },
    inputText: {
      fontSize: 17
    }
  }
};

// src/components/input/useDebouncedValue.ts
import { useEffect as useEffect4, useState as useState4 } from "react";
var useDebouncedValue = (value, delay = 250) => {
  const [debouncedValue, setDebouncedValue] = useState4(value);
  useEffect4(() => {
    const timeoutId = setTimeout(() => {
      setDebouncedValue(value);
    }, delay);
    return () => {
      clearTimeout(timeoutId);
    };
  }, [value, delay]);
  return debouncedValue;
};

// src/components/input/AnimatedPlaceholder.tsx
import React15, { useEffect as useEffect5, useMemo as useMemo7, useRef as useRef3, useState as useState5 } from "react";
import { Animated as Animated3, StyleSheet as StyleSheet11 } from "react-native";
var HEIGHT_MULTIPLIER_UP = 1.6;
var HEIGHT_MULTIPLIER_DOWN = 1.8;
function AnimatedPlaceholder(props) {
  const { colors } = useBlossomTheme();
  const {
    placeholders = [],
    visible = true,
    duration = 500,
    containerStyle,
    textStyle
  } = props;
  const [currentIndex, setCurrentIndex] = useState5(0);
  const [viewHeight, setViewHeight] = useState5(48);
  const translateY = useRef3(new Animated3.Value(0)).current;
  const animationLoop = useMemo7(
    () => Animated3.loop(
      Animated3.sequence([
        Animated3.timing(translateY, {
          toValue: 1,
          duration,
          delay: 1e3,
          useNativeDriver: true
        }),
        Animated3.timing(translateY, {
          toValue: 2,
          duration: 10,
          useNativeDriver: true
        }),
        Animated3.timing(translateY, {
          toValue: 3,
          duration,
          useNativeDriver: true
        })
      ])
    ),
    [duration, translateY]
  );
  useEffect5(() => {
    if (visible) {
      animationLoop.start();
    } else {
      animationLoop.reset();
    }
    return () => {
      animationLoop.reset();
    };
  }, [animationLoop, duration, translateY, visible]);
  useEffect5(() => {
    translateY.addListener(({ value }) => {
      if (value === 2) {
        setCurrentIndex((prevIndex) => (prevIndex + 0.5) % placeholders.length);
      }
    });
    return () => {
      animationLoop.reset();
      translateY.removeAllListeners();
    };
  }, []);
  if (!visible || placeholders.length === 0) return null;
  return /* @__PURE__ */ React15.createElement(
    View_default,
    {
      style: [styles11.innerContainer, containerStyle],
      onLayout: (e) => {
        const { height } = e.nativeEvent.layout;
        setViewHeight(height);
      }
    },
    /* @__PURE__ */ React15.createElement(
      Animated3.Text,
      {
        style: [
          {
            color: colors.text100
          },
          {
            transform: [
              {
                translateY: translateY.interpolate({
                  inputRange: [0, 1, 2, 3],
                  outputRange: [
                    0,
                    -viewHeight * HEIGHT_MULTIPLIER_UP,
                    viewHeight * HEIGHT_MULTIPLIER_DOWN,
                    0
                  ]
                })
              }
            ]
          },
          {
            opacity: translateY.interpolate({
              inputRange: [0, 1, 2, 3],
              outputRange: [1, 0.5, 0.5, 1]
            })
          },
          textStyle
        ]
      },
      placeholders[currentIndex] || ""
    )
  );
}
var AnimatedPlaceholder_default = AnimatedPlaceholder;
var styles11 = StyleSheet11.create({
  innerContainer: {
    position: "absolute",
    backgroundColor: "transparent"
  }
});

// src/components/input/SearchInput.tsx
var SearchInput = (props, ref) => {
  const { colors, isDark } = useBlossomTheme();
  const {
    debounceDelay,
    onQueryChange,
    status,
    animatedPlaceholderProps,
    ...rest
  } = useMergedProps("SearchInput", props, { colors, isDark });
  const [searchQuery, setSearchQuery] = useState6("");
  const debouncedValue = useDebouncedValue(searchQuery, debounceDelay);
  const [leftWidth, setLeftWidth] = useState6(18);
  const onClearPress = useCallback6(() => {
    setSearchQuery("");
  }, []);
  useEffect6(() => {
    onQueryChange?.(debouncedValue);
  }, [debouncedValue, onQueryChange]);
  return /* @__PURE__ */ React16.createElement(
    TextInput_default,
    {
      ref,
      value: searchQuery,
      onChangeText: setSearchQuery,
      right: searchQuery ? /* @__PURE__ */ React16.createElement(
        Icon_default,
        {
          family: "Ionicons",
          status,
          name: "close",
          size: 18,
          onPress: onClearPress
        }
      ) : null,
      placeholderComponent: animatedPlaceholderProps?.placeholders?.length ? /* @__PURE__ */ React16.createElement(
        AnimatedPlaceholder_default,
        {
          ...animatedPlaceholderProps,
          visible: !searchQuery,
          containerStyle: [
            {
              paddingLeft: leftWidth + (!rest?.mode || rest?.mode === "outlined" ? textInputSizeStylesMap[rest?.size || "medium"].outlined.padding : 0)
            },
            animatedPlaceholderProps?.containerStyle
          ],
          textStyle: [
            {
              color: colors.text400
            },
            animatedPlaceholderProps?.textStyle
          ]
        }
      ) : null,
      ...rest,
      left: /* @__PURE__ */ React16.createElement(
        View_default,
        {
          onLayout: ({ nativeEvent }) => {
            setLeftWidth(nativeEvent.layout.width + 6);
          }
        },
        rest?.left || /* @__PURE__ */ React16.createElement(Icon_default, { family: "Ionicons", status, name: "search", size: 18 })
      )
    }
  );
};
var SearchInput_default = forwardRef4(SearchInput);

// src/components/input/OtpInput.tsx
import React17, {
  forwardRef as forwardRef5,
  useCallback as useCallback7,
  useEffect as useEffect7,
  useImperativeHandle,
  useMemo as useMemo8,
  useRef as useRef4,
  useState as useState7
} from "react";
import {
  Animated as Animated4,
  Easing as Easing2,
  StyleSheet as StyleSheet12,
  TouchableWithoutFeedback
} from "react-native";
var OtpInput = (props, ref) => {
  const { colors, isDark } = useBlossomTheme();
  const {
    maxLength = 4,
    boxStyle,
    mode = "box",
    withAlphanumericKeyboard,
    withCursor,
    onComplete,
    status = "primary",
    size = "medium",
    ...rest
  } = useMergedProps("OtpInput", props, { colors, isDark });
  const [otp, setOtp] = useState7("");
  const [isFocused, setIsFocused] = useState7(false);
  const inputRef = useRef4(null);
  const cursorOpacity = useRef4(new Animated4.Value(0)).current;
  const onInputChange = useCallback7(
    (text) => {
      setOtp(text);
      if (text.length === maxLength) {
        onComplete?.(text);
      }
    },
    [maxLength, onComplete]
  );
  const getOtpInputText = useCallback7(
    (value, label) => {
      if (value) {
        return rest?.secureTextEntry ? "*" : value;
      }
      return label || "";
    },
    [rest?.secureTextEntry]
  );
  useImperativeHandle(ref, () => {
    return {
      clear: () => {
        inputRef.current?.clear();
      }
    };
  }, []);
  const cursorLoop = useMemo8(() => {
    return Animated4.loop(
      Animated4.sequence([
        Animated4.timing(cursorOpacity, {
          toValue: 0.5,
          duration: 500,
          easing: Easing2.ease,
          useNativeDriver: true
        }),
        Animated4.timing(cursorOpacity, {
          toValue: 1,
          duration: 500,
          easing: Easing2.ease,
          useNativeDriver: true
        })
      ])
    );
  }, [cursorOpacity]);
  useEffect7(() => {
    if (withCursor && isFocused && otp.length !== maxLength) {
      cursorLoop.start();
    } else {
      cursorLoop.reset();
    }
  }, [cursorLoop, isFocused, maxLength, otp.length, withCursor]);
  return /* @__PURE__ */ React17.createElement(
    TouchableWithoutFeedback,
    {
      accessibilityRole: "button",
      onPress: () => inputRef.current?.focus()
    },
    /* @__PURE__ */ React17.createElement(View_default, { style: styles12.container }, /* @__PURE__ */ React17.createElement(
      TextInput_default,
      {
        ref: inputRef,
        accessibilityLabel: "Text input field",
        containerStyle: styles12.inputContainer,
        value: otp,
        onChangeText: onInputChange,
        maxLength,
        keyboardType: withAlphanumericKeyboard ? "default" : "numeric",
        textContentType: "oneTimeCode",
        autoComplete: "one-time-code",
        onFocus: (e) => {
          setIsFocused(true);
          rest?.onFocus?.(e);
        },
        onBlur: (e) => {
          setIsFocused(false);
          rest?.onBlur?.(e);
        },
        ...rest
      }
    ), /* @__PURE__ */ React17.createElement(View_default, { row: true, style: [styles12.boxRow] }, Array(maxLength).fill(rest?.placeholder || "").map((label, index) => /* @__PURE__ */ React17.createElement(
      View_default,
      {
        key: index,
        style: [
          mode === "box" ? styles12.box : styles12.dash,
          styles12.boxRow,
          {
            width: sizeMap3[size],
            height: sizeMap3[size],
            borderColor: otp.length === index && isFocused ? colors[getStatusColorName(status)] : colors.background800
          },
          typeof boxStyle === "function" ? boxStyle?.(otp.length === index && isFocused) : boxStyle
        ]
      },
      rest?.secureTextEntry && otp.charAt(index) ? /* @__PURE__ */ React17.createElement(
        View_default,
        {
          style: [
            styles12.dot,
            {
              backgroundColor: colors.background900
            }
          ]
        }
      ) : /* @__PURE__ */ React17.createElement(
        SizedText_default,
        {
          mode: "body",
          style: [
            [
              {
                color: otp.charAt(index) ? colors.text100 : colors.text500
              },
              rest?.textStyle
            ]
          ]
        },
        otp.charAt(index) || label || ""
      ),
      otp.length === index && isFocused && !otp.charAt(index) && /* @__PURE__ */ React17.createElement(
        Animated4.View,
        {
          style: [
            styles12.cursor,
            {
              opacity: cursorOpacity,
              backgroundColor: colors.text100
            }
          ]
        }
      )
    ))))
  );
};
var OtpInput_default = forwardRef5(OtpInput);
var DOT_SIZE = 10;
var styles12 = StyleSheet12.create({
  container: {
    position: "relative",
    alignSelf: "center"
  },
  inputContainer: {
    position: "absolute",
    width: 100,
    height: 40,
    opacity: 0
  },
  boxRow: {
    alignItems: "center",
    justifyContent: "center"
  },
  box: {
    margin: 6,
    borderWidth: 1,
    borderRadius: 10
  },
  dash: {
    margin: 6,
    borderBottomWidth: 1
  },
  dot: {
    borderRadius: DOT_SIZE,
    width: DOT_SIZE,
    height: DOT_SIZE
  },
  cursor: {
    position: "absolute",
    height: "50%",
    width: 1.25
  }
});
var sizeMap3 = {
  small: 36,
  medium: 40,
  large: 50
};

// src/components/image/Avatar.tsx
import React18, { forwardRef as forwardRef6 } from "react";
import { Image, StyleSheet as StyleSheet13, TouchableOpacity as TouchableOpacity4 } from "react-native";
var Avatar = (props, ref) => {
  const { colors, isDark, options } = useBlossomTheme();
  const {
    mode = "circle",
    icon,
    url,
    initials,
    initialStyle,
    status = "primary",
    size = "medium",
    onPress,
    ...rest
  } = useMergedProps("Avatar", props, { colors, isDark });
  const borderRadiusMap = {
    circle: typeof size === "number" ? size : sizeMap4[size] / 2,
    round: options?.borderRadius || 0,
    square: 0
  };
  const imageStyle = {
    width: typeof size === "number" ? size : sizeMap4[size],
    height: typeof size === "number" ? size : sizeMap4[size],
    borderColor: colors[getBorderColorName(status, isDark)],
    backgroundColor: colors[getStatusColorName(status, isDark, "200")],
    borderRadius: borderRadiusMap[mode]
  };
  const Container = onPress ? TouchableOpacity4 : View_default;
  return /* @__PURE__ */ React18.createElement(
    Container,
    {
      activeOpacity: 0.75,
      ...rest,
      style: [imageStyle, styles13.container, rest?.style],
      onPress
    },
    rest?.source || url ? (
      // eslint-disable-next-line @typescript-eslint/ban-ts-comment
      // @ts-ignore
      /* @__PURE__ */ React18.createElement(
        Image,
        {
          ref,
          accessibilityIgnoresInvertColors: true,
          source: {
            uri: url
          },
          ...rest,
          style: [imageStyle]
        }
      )
    ) : icon ? icon(imageStyle.width - OFFSET) : initials ? /* @__PURE__ */ React18.createElement(
      Text_default,
      {
        typography: "h6",
        style: [
          {
            color: colors.bgLight100,
            fontSize: imageStyle.width / 2
          },
          styles13.text,
          initialStyle
        ]
      },
      initials
    ) : /* @__PURE__ */ React18.createElement(
      Icon_default,
      {
        family: "MaterialCommunityIcons",
        name: "account",
        size: imageStyle.width - OFFSET,
        color: "white"
      }
    )
  );
};
var Avatar_default = forwardRef6(Avatar);
var styles13 = StyleSheet13.create({
  container: {
    justifyContent: "center",
    alignItems: "center"
  },
  text: {
    fontWeight: "600"
  }
});
var sizeMap4 = {
  small: 40,
  medium: 64,
  large: 96
};
var OFFSET = 8;

// src/components/formFields/Switch.tsx
import React20, { forwardRef as forwardRef7, useEffect as useEffect8, useState as useState8 } from "react";
import { Platform as Platform4, Switch as RNSwitch, StyleSheet as StyleSheet15 } from "react-native";

// src/components/formFields/BaseBooleanField.tsx
import React19 from "react";
import { StyleSheet as StyleSheet14 } from "react-native";
var BaseBooleanField = (props) => {
  const { colors, isDark } = useBlossomTheme();
  const {
    label,
    caption,
    error,
    disabled,
    position = "left",
    adjacent = true,
    containerStyle,
    labelStyle,
    captionStyle,
    errorStyle,
    status = "accent",
    size = "medium",
    children
  } = props;
  return /* @__PURE__ */ React19.createElement(
    View_default,
    {
      style: [
        styles14.outerContainer,
        position === "right" ? styles14.positionRight : {},
        !adjacent && styles14.apart,
        containerStyle
      ]
    },
    children,
    /* @__PURE__ */ React19.createElement(
      View_default,
      {
        style: [
          { borderColor: colors[getBorderColorName(status, isDark)] },
          position === "right" || !adjacent ? styles14.alignEndRightPosition : {},
          position === "right" && !adjacent && styles14.alignLeftRightPosition,
          position === "left" ? styles14.startMargin : styles14.endMargin,
          containerStyle
        ]
      },
      label ? /* @__PURE__ */ React19.createElement(
        SizedText_default,
        {
          size,
          style: [
            styles14.label,
            disabled && {
              color: colors.text400
            },
            labelStyle
          ]
        },
        label
      ) : null,
      caption ? /* @__PURE__ */ React19.createElement(SizedText_default, { size, mode: "caption", style: [captionStyle] }, caption) : null,
      error ? /* @__PURE__ */ React19.createElement(SizedText_default, { size, status: "error", style: [errorStyle] }, error) : null
    )
  );
};
var BaseBooleanField_default = BaseBooleanField;
var styles14 = StyleSheet14.create({
  alignLeftRightPosition: {
    alignItems: void 0
  },
  outerContainer: {
    flexDirection: "row",
    alignItems: "center",
    backgroundColor: "transparent"
  },
  alignEndRightPosition: {
    alignItems: "flex-end"
  },
  positionRight: {
    flexDirection: "row-reverse"
  },
  apart: {
    justifyContent: "space-between"
  },
  label: {
    fontWeight: "500"
  },
  startMargin: {
    marginStart: 12
  },
  endMargin: {
    marginEnd: 12
  }
});

// src/components/formFields/Switch.tsx
var Switch = (props, ref) => {
  const { colors, isDark } = useBlossomTheme();
  const {
    value,
    disabled,
    onValueChange,
    color,
    style: switchStyle,
    status = "accent",
    size = "medium",
    ...rest
  } = useMergedProps("Switch", props, { colors, isDark });
  const [fieldValue, setFieldValue] = useState8(value);
  useEffect8(() => {
    setFieldValue(value);
  }, [value]);
  return /* @__PURE__ */ React20.createElement(BaseBooleanField_default, { status, size, disabled, ...rest }, /* @__PURE__ */ React20.createElement(
    RNSwitch,
    {
      ref,
      value: fieldValue,
      trackColor: {
        true: disabled ? colors.bgDark100 : color || colors[getBorderColorName(status, isDark)],
        false: isDark ? colors.background400 : colors.background300
      },
      thumbColor: colors.bgLight100,
      ...Platform4.select({
        web: {
          activeThumbColor: colors.bgLight100
        }
      }),
      disabled,
      ios_backgroundColor: isDark ? colors.background400 : colors.background300,
      ...rest,
      style: [
        { transform: [{ scaleX: sizeMap5[size] }, { scaleY: sizeMap5[size] }] },
        size === "small" && styles15.sizeSmall,
        size === "large" && styles15.sizeLarge,
        switchStyle
      ],
      onValueChange: () => {
        setFieldValue((prev) => {
          void onValueChange?.(!prev);
          return !prev;
        });
      }
    }
  ));
};
var Switch_default = forwardRef7(Switch);
var styles15 = StyleSheet15.create({
  sizeSmall: {
    marginHorizontal: -6
  },
  sizeLarge: {
    marginHorizontal: 6
  }
});
var sizeMap5 = {
  small: 0.6,
  medium: 0.8,
  large: 1
};

// src/components/formFields/Checkbox.tsx
import React21, { useCallback as useCallback8, useEffect as useEffect9, useState as useState9 } from "react";
import { Pressable as Pressable2, StyleSheet as StyleSheet16 } from "react-native";
var OFFSET_SIZE = 4;
var Checkbox = (props) => {
  const { colors, isDark } = useBlossomTheme();
  const {
    value,
    onValueChange,
    indeterminate,
    disabled,
    color,
    style,
    checkedIcon,
    uncheckedIcon,
    status = "accent",
    size = "medium",
    ...rest
  } = useMergedProps("Checkbox", props, { colors, isDark });
  const [fieldValue, setFieldValue] = useState9(value);
  useEffect9(() => {
    setFieldValue(value);
  }, [value]);
  const getBgColor = useCallback8(() => {
    if (disabled) return isDark ? colors.bgDark400 : colors.bgLight400;
    if (fieldValue) return color || colors[getStatusColorName(status, isDark)];
    return isDark ? colors.bgDark800 : colors.bgLight200;
  }, [disabled, colors, fieldValue, color, status, isDark]);
  const getIconName = useCallback8(() => {
    if (indeterminate) return "minus";
    return "check";
  }, [indeterminate]);
  const getIconColor = useCallback8(() => {
    if (disabled) return colors.bgDark100;
    return colors.bgLight100;
  }, [colors, disabled]);
  return /* @__PURE__ */ React21.createElement(BaseBooleanField_default, { status, size, disabled, ...rest }, /* @__PURE__ */ React21.createElement(
    Pressable2,
    {
      accessibilityRole: "button",
      style: [
        styles16.checkbox,
        size === "small" && styles16.checkboxSmall,
        !uncheckedIcon && {
          width: sizeMap6[size],
          height: sizeMap6[size],
          backgroundColor: getBgColor(),
          borderColor: colors.background300,
          borderWidth: fieldValue ? 0 : 1
        },
        style
      ],
      onPress: () => {
        if (disabled) return;
        setFieldValue?.(indeterminate ? true : !fieldValue);
        void onValueChange?.(indeterminate ? true : !fieldValue);
      }
    },
    fieldValue || indeterminate ? checkedIcon || /* @__PURE__ */ React21.createElement(
      Icon_default,
      {
        family: "MaterialCommunityIcons",
        name: getIconName(),
        size: sizeMap6[size] - OFFSET_SIZE,
        color: getIconColor()
      }
    ) : uncheckedIcon
  ));
};
var Checkbox_default = Checkbox;
var styles16 = StyleSheet16.create({
  checkbox: {
    borderRadius: 8,
    justifyContent: "center",
    alignItems: "center",
    alignSelf: "center"
  },
  checkboxSmall: {
    borderRadius: 6
  }
});
var sizeMap6 = {
  small: 20,
  medium: 26,
  large: 32
};

// src/components/formFields/Radio.tsx
import React22, { useCallback as useCallback9, useEffect as useEffect10, useState as useState10 } from "react";
var Radio = (props) => {
  const { colors, isDark } = useBlossomTheme();
  const {
    value,
    onValueChange,
    disabled,
    style,
    color,
    status = "accent",
    size = "medium",
    ...rest
  } = useMergedProps("Radio", props, { colors, isDark });
  const [fieldValue, setFieldValue] = useState10(value);
  useEffect10(() => {
    setFieldValue(value);
  }, [value]);
  const getBgColor = useCallback9(() => {
    if (disabled) return colors.bgDark100;
    return colors[getStatusColorName(status, isDark)];
  }, [disabled, colors, status, isDark]);
  const getIconName = useCallback9(() => {
    if (fieldValue) return "radiobox-marked";
    return "radiobox-blank";
  }, [fieldValue]);
  return /* @__PURE__ */ React22.createElement(BaseBooleanField_default, { status, size, disabled, ...rest }, /* @__PURE__ */ React22.createElement(
    Icon_default,
    {
      family: "MaterialCommunityIcons",
      name: getIconName(),
      size: sizeMap7[size],
      onPress: fieldValue || disabled ? void 0 : () => {
        setFieldValue(true);
        void onValueChange?.(true);
      },
      color: color || getBgColor()
    }
  ));
};
var Radio_default = Radio;
var sizeMap7 = {
  small: 20,
  medium: 26,
  large: 32
};

// src/components/button/FAB.tsx
import React24 from "react";
import { StyleSheet as StyleSheet18 } from "react-native";

// src/components/button/BaseButton.tsx
import React23, { useCallback as useCallback10, useEffect as useEffect11, useMemo as useMemo9 } from "react";
import { Pressable as Pressable3, StyleSheet as StyleSheet17 } from "react-native";

// src/components/button/helper.ts
var ColorHelper = {
  /**
   * @returns text color based on theme color which is evaluated based on status, mode & backgroundColor and it's luminance value
   */
  getTextColor: ({
    status,
    mode,
    backgroundColor,
    disabled,
    colors,
    isDark
  }) => {
    const color = disabled || mode === "filled" ? colors[getTextColorName(backgroundColor, isDark, disabled, mode)] : colors[getStatusColorName(status, isDark)];
    return color;
  },
  /**
   * @returns button background color based on it's status and mode
   */
  getButtonColor: ({
    status,
    mode,
    disabled,
    colors,
    isDark
  }) => {
    const modeColorMap = {
      filled: {
        true: colors.background300,
        false: colors[getStatusColorName(status, isDark)]
      },
      tinted: {
        true: colors.background200,
        false: colors[getTransparentStatusColorName(status, isDark ? "200" : "100")]
      },
      outlined: {
        true: colors.background100,
        false: colors.background100
      },
      plain: {
        true: colors.background100,
        false: colors.background100
      }
    };
    const color = modeColorMap[mode][disabled ? "true" : "false"];
    return color;
  },
  /**
   * @returns hovered & pressed color of the button based on it's status & mode which will be it's lighter/transparent color
   */
  getButtonStateColor({
    state,
    status,
    mode,
    backgroundColor,
    disabled,
    colors,
    isDark
  }) {
    const bgColor = backgroundColor;
    const buttonColor = this.getButtonColor({
      status,
      mode,
      disabled,
      colors,
      isDark
    });
    const hoverColorMap = {
      filled: `${status}600`,
      tinted: `${status}Transparent${isDark ? "300" : "200"}`,
      outlined: `${status}Transparent${isDark ? "200" : "100"}`,
      plain: `${status}Transparent${isDark ? "200" : "100"}`
    };
    const pressColorMap = {
      filled: `${status}700`,
      tinted: `${status}Transparent${isDark ? "400" : "300"}`,
      outlined: `${status}Transparent${isDark ? "300" : "200"}`,
      plain: `${status}Transparent${isDark ? "300" : "200"}`
    };
    let color = colors[state === "pressed" ? pressColorMap[mode] : hoverColorMap[mode]];
    if (bgColor !== buttonColor) {
      const alphaColorMap = {
        hovered: mode === "filled" ? 0.6 : 0.4,
        pressed: mode === "filled" ? 0.8 : 0.5
      };
      color = getDarkenColor(bgColor, alphaColorMap[state]);
    }
    return color;
  }
};

// src/components/button/BaseButton.tsx
var BaseButton = (props) => {
  const { colors, isDark, options } = useBlossomTheme();
  const {
    title,
    style,
    titleStyle,
    isLoading = false,
    viewOnly,
    disabled,
    children,
    status = "primary",
    mode = "filled",
    size = "medium",
    left,
    right,
    onPress,
    loaderProps,
    disabledStyle,
    disabledTitleStyle,
    onTextColorChange,
    onBackgroundColorChange,
    ...rest
  } = props;
  const buttonBackgroundColor = useMemo9(() => {
    const color = ColorHelper.getButtonColor({
      status,
      mode,
      disabled,
      colors,
      isDark
    });
    return color;
  }, [colors, status, isDark, mode, disabled]);
  const containerStyle = useMemo9(
    () => StyleSheet17.flatten([
      {
        backgroundColor: buttonBackgroundColor,
        borderColor: disabled ? colors.background400 : colors[getStatusColorName(status, isDark, "500")],
        borderRadius: options?.borderRadius
      },
      disabled && disabledStyle,
      mode === "outlined" ? styles17.outlinedButton : {},
      styles17.buttonContainer,
      sizeStyle[size],
      style
    ]),
    [
      status,
      mode,
      disabled,
      colors,
      isDark,
      style,
      size,
      options?.borderRadius,
      disabledStyle,
      buttonBackgroundColor
    ]
  );
  const getButtonStateColor = useCallback10(
    (state) => {
      const color = ColorHelper.getButtonStateColor({
        state,
        status,
        mode,
        backgroundColor: containerStyle?.backgroundColor,
        disabled,
        colors,
        isDark
      });
      return color;
    },
    [status, mode, containerStyle?.backgroundColor, disabled, colors, isDark]
  );
  const textColor = useMemo9(() => {
    const color = ColorHelper.getTextColor({
      status,
      mode,
      backgroundColor: containerStyle?.backgroundColor,
      disabled,
      colors,
      isDark
    });
    onTextColorChange?.(color);
    return color;
  }, [
    status,
    mode,
    containerStyle?.backgroundColor,
    disabled,
    colors,
    isDark,
    onTextColorChange
  ]);
  useEffect11(() => {
    onBackgroundColorChange?.(buttonBackgroundColor);
  }, [buttonBackgroundColor, onBackgroundColorChange]);
  useEffect11(() => {
    onTextColorChange?.(textColor);
  }, [textColor, onTextColorChange]);
  return /* @__PURE__ */ React23.createElement(
    Pressable3,
    {
      ...rest,
      disabled: viewOnly || disabled,
      style: ({ pressed, hovered, focused }) => {
        return [
          containerStyle,
          (pressed || hovered) && !isLoading && !disabled && {
            backgroundColor: getButtonStateColor(
              pressed ? "pressed" : "hovered"
            )
          }
        ];
      },
      onPress: isLoading || disabled ? void 0 : onPress
    },
    /* @__PURE__ */ React23.createElement(
      ActivityIndicator_default,
      {
        visible: isLoading,
        size: 16,
        style: styles17.loader,
        color: textColor,
        ...loaderProps
      }
    ),
    left,
    children || title ? /* @__PURE__ */ React23.createElement(
      Text_default,
      {
        typography: sizeMap8[size],
        style: [
          {
            color: textColor
          },
          disabled && disabledTitleStyle,
          styles17.text,
          titleStyle
        ],
        selectable: false
      },
      children || title
    ) : null,
    right
  );
};
var BaseButton_default = BaseButton;
var styles17 = StyleSheet17.create({
  buttonContainer: {
    flexDirection: "row",
    alignSelf: "baseline",
    justifyContent: "center"
  },
  text: {
    alignSelf: "center",
    paddingHorizontal: 6
  },
  outlinedButton: {
    borderWidth: 1
  },
  loader: {
    paddingHorizontal: 4
  }
});
var sizeStyle = {
  small: {
    paddingHorizontal: 8,
    paddingVertical: 9
  },
  medium: {
    paddingHorizontal: 13,
    // 3 coming from text style
    paddingVertical: 12
  },
  large: {
    paddingHorizontal: 16,
    paddingVertical: 15
  }
};
var sizeMap8 = {
  small: "l1",
  medium: "b1",
  large: "s1"
};

// src/components/button/FAB.tsx
var FAB = (props) => {
  const { colors, isDark } = useBlossomTheme();
  const {
    icon,
    offsetX = 48,
    offsetY = 48,
    ...rest
  } = useMergedProps("FAB", props, { colors, isDark });
  return /* @__PURE__ */ React24.createElement(
    BaseButton_default,
    {
      left: icon,
      ...rest,
      style: [
        styles18.absolute,
        {
          right: offsetX,
          bottom: offsetY
        },
        rest.style
      ]
    }
  );
};
var FAB_default = FAB;
var styles18 = StyleSheet18.create({
  absolute: {
    position: "absolute"
  }
});

// src/components/button/Chip.tsx
import React25, { useEffect as useEffect12, useMemo as useMemo10, useState as useState11 } from "react";
import { StyleSheet as StyleSheet19 } from "react-native";
var Chip = (props) => {
  const { colors, isDark } = useBlossomTheme();
  const {
    isSelected,
    withCheckIcon,
    checkIcon,
    clearable,
    viewOnly,
    asBadge,
    onClearPress,
    mode = "filled",
    size = "medium",
    ...rest
  } = useMergedProps("Chip", props, {
    colors,
    isDark
  });
  const [isChipSelected, setIsChipSelected] = useState11(isSelected);
  const [backgroundColor, setBackgroundColor] = useState11("");
  useEffect12(() => {
    setIsChipSelected(isSelected);
  }, [isSelected]);
  const iconColor = useMemo10(() => {
    return mode === "tinted" ? colors.text100 : colors[getTextColorName(backgroundColor, isDark, rest.disabled, mode)];
  }, [backgroundColor, colors, isDark, mode, rest.disabled]);
  return (
    // NOTE: this view wrapper is needed to fix the vertical align issue in row
    /* @__PURE__ */ React25.createElement(View_default, null, /* @__PURE__ */ React25.createElement(
      BaseButton_default,
      {
        ...rest,
        mode,
        viewOnly: viewOnly || asBadge,
        style: [sizeStyle2[size], asBadge && styles19.badge, rest.style],
        titleStyle: [sizeMap9[size], rest?.titleStyle],
        left: /* @__PURE__ */ React25.createElement(View_default, { row: true, style: styles19.row }, withCheckIcon && isChipSelected && (checkIcon || /* @__PURE__ */ React25.createElement(
          Icon_default,
          {
            family: "Ionicons",
            name: "checkmark-sharp",
            color: iconColor,
            size: checkIconSize[size]
          }
        )), rest?.left),
        right: /* @__PURE__ */ React25.createElement(View_default, { row: true, style: styles19.row }, clearable && /* @__PURE__ */ React25.createElement(
          Icon_default,
          {
            family: "Ionicons",
            name: "close",
            size: checkIconSize[size],
            style: styles19.closeIcon,
            color: iconColor,
            onPress: () => {
              onClearPress?.();
            }
          }
        ), rest?.right),
        onPress: (e) => {
          !viewOnly && setIsChipSelected((prev) => !prev);
          rest?.onPress?.(e);
        },
        onBackgroundColorChange: setBackgroundColor
      }
    ))
  );
};
var Chip_default = Chip;
var styles19 = StyleSheet19.create({
  row: {
    backgroundColor: "transparent",
    alignSelf: "baseline",
    alignItems: "center"
  },
  closeIcon: {
    paddingHorizontal: 2
  },
  badge: {
    paddingHorizontal: 0,
    paddingVertical: 0
  }
});
var sizeStyle2 = {
  small: {
    paddingHorizontal: 4,
    paddingVertical: 2
  },
  medium: {
    paddingHorizontal: 6,
    paddingVertical: 4
  },
  large: {
    paddingHorizontal: 8,
    paddingVertical: 6
  }
};
var sizeMap9 = {
  small: {
    fontSize: 13
  },
  medium: {
    fontSize: 14
  },
  large: {
    fontSize: 16
  }
};
var checkIconSize = {
  small: 14,
  medium: 16,
  large: 18
};

// src/components/button/Button.tsx
import React26 from "react";
var Button = (props) => {
  const { colors, isDark } = useBlossomTheme();
  const { ...rest } = useMergedProps("Button", props, { colors, isDark });
  return /* @__PURE__ */ React26.createElement(BaseButton_default, { ...rest });
};
var Button_default = Button;

// src/components/button/SegmentedButton.tsx
import React27, { useCallback as useCallback11, useState as useState12 } from "react";
import { StyleSheet as StyleSheet20 } from "react-native";
var SegmentedButton = (props) => {
  const { colors, isDark, options } = useBlossomTheme();
  const {
    data = [],
    fullWidth,
    borderRadius,
    withVerticalDivider,
    multiSelect,
    activeColor,
    inactiveColor,
    onPress,
    status = "primary",
    mode,
    size = "medium",
    ...rest
  } = useMergedProps("SegmentedButton", props, { colors, isDark });
  const [selectedIndexes, setSelectedIndexes] = useState12([]);
  const getMode = useCallback11(
    (index) => {
      return rest.disabled ? "tinted" : mode || (selectedIndexes.includes(index) ? "tinted" : "outlined");
    },
    [mode, rest.disabled, selectedIndexes]
  );
  return /* @__PURE__ */ React27.createElement(View_default, { row: true, style: [styles20.container, rest.style] }, data?.map((item, index) => /* @__PURE__ */ React27.createElement(
    Chip_default,
    {
      key: item.value || item.label || index,
      mode: getMode(index),
      titleStyle: [
        getMode(index) !== "filled" && {
          color: colors.text200
        },
        (rest.disabled || item.disabled) && {
          color: colors.text500
        }
      ],
      status,
      size,
      withCheckIcon: true,
      ...item,
      isSelected: item.isSelected || selectedIndexes.includes(index),
      disabled: item.disabled || rest.disabled,
      style: [
        styles20.itemButton,
        sizeStyle3[size],
        {
          borderColor: colors.background900
        },
        activeColor && selectedIndexes.includes(index) ? {
          backgroundColor: activeColor
        } : {},
        inactiveColor && !selectedIndexes.includes(index) ? {
          backgroundColor: inactiveColor
        } : {},
        index === 0 && {
          borderTopLeftRadius: borderRadius || options?.borderRadius,
          borderBottomLeftRadius: borderRadius || options?.borderRadius
        },
        index === data.length - 1 && {
          borderTopRightRadius: borderRadius || options?.borderRadius,
          borderBottomRightRadius: borderRadius || options?.borderRadius
        },
        index !== data.length - 1 && withVerticalDivider && {
          borderEndWidth: 0.1,
          borderColor: colors.background500
        },
        item.style
      ],
      onPress: () => {
        setSelectedIndexes((prev) => {
          if (prev.includes(index)) {
            return prev.filter((itemValue) => itemValue !== index);
          }
          return multiSelect ? prev.concat(index) : [index];
        });
        onPress?.(item.value || item.label || "", index);
      }
    }
  )));
};
var SegmentedButton_default = SegmentedButton;
var styles20 = StyleSheet20.create({
  container: {
    alignSelf: "baseline"
  },
  control: {
    padding: 8
  },
  label: {
    paddingStart: 4
  },
  itemButton: {
    borderRadius: 0,
    // TODO handle left and right width
    borderWidth: 0.5
  }
});
var sizeStyle3 = {
  small: {
    paddingVertical: 6
  },
  medium: {
    paddingVertical: 9
  },
  large: {
    paddingVertical: 12
  }
};

// src/components/modal/Modal.tsx
import React28 from "react";
import { Platform as Platform5, Pressable as Pressable4, Modal as RNModal, StyleSheet as StyleSheet21 } from "react-native";
var Modal = (props) => {
  const { colors, isDark, options } = useBlossomTheme();
  const {
    visible,
    onBackdropPress,
    children,
    style,
    backdropStyle,
    contentStyle,
    ...rest
  } = useMergedProps("Modal", props, { colors, isDark });
  const { isLandscape } = useDeviceInfo();
  return /* @__PURE__ */ React28.createElement(
    RNModal,
    {
      transparent: true,
      visible,
      supportedOrientations: ["portrait", "landscape"],
      ...rest
    },
    /* @__PURE__ */ React28.createElement(
      Pressable4,
      {
        accessibilityRole: "alert",
        style: [
          styles21.backdrop,
          {
            backgroundColor: getAlphaColor(colors.bgDark900, 0.65)
          },
          backdropStyle
        ],
        onPress: onBackdropPress
      },
      /* @__PURE__ */ React28.createElement(Pressable4, { accessibilityRole: "alert" }, /* @__PURE__ */ React28.createElement(
        View_default,
        {
          accessibilityRole: "alert",
          style: [
            styles21.content,
            isLandscape && styles21.landscape,
            {
              borderRadius: options?.borderRadius
            },
            contentStyle
          ]
        },
        children
      ))
    )
  );
};
var Modal_default = Modal;
var styles21 = StyleSheet21.create({
  backdrop: {
    flex: 1,
    justifyContent: "center"
  },
  content: {
    margin: 24,
    padding: 16,
    borderRadius: 8,
    maxHeight: 400,
    ...Platform5.select({
      web: {
        alignSelf: "center",
        maxWidth: 500,
        minWidth: 300
      }
    })
  },
  landscape: {
    marginHorizontal: "25%"
  }
});

// src/components/modal/BottomSheet.tsx
import React29 from "react";
import { Platform as Platform6, Pressable as Pressable5, Modal as RNModal2, StyleSheet as StyleSheet22 } from "react-native";
var BottomSheet = (props) => {
  const { colors, isDark, options } = useBlossomTheme();
  const {
    visible,
    onBackdropPress,
    children,
    style,
    backdropStyle,
    contentStyle,
    ...rest
  } = useMergedProps("BottomSheet", props, { colors, isDark });
  return /* @__PURE__ */ React29.createElement(
    RNModal2,
    {
      transparent: true,
      animationType: "slide",
      visible,
      supportedOrientations: ["portrait", "landscape"],
      ...rest
    },
    /* @__PURE__ */ React29.createElement(
      Pressable5,
      {
        accessibilityRole: "alert",
        style: [
          styles22.backdrop,
          {
            backgroundColor: getAlphaColor(colors.bgDark900, 0.1)
          },
          backdropStyle
        ],
        onPress: onBackdropPress
      },
      /* @__PURE__ */ React29.createElement(Pressable5, { accessibilityRole: "alert" }, /* @__PURE__ */ React29.createElement(
        View_default,
        {
          accessibilityRole: "alert",
          style: [
            styles22.content,
            {
              borderRadius: options?.borderRadius
            },
            contentStyle
          ]
        },
        children
      ))
    )
  );
};
var BottomSheet_default = BottomSheet;
var styles22 = StyleSheet22.create({
  backdrop: {
    flex: 1,
    justifyContent: "flex-end"
  },
  content: {
    padding: 16,
    borderBottomLeftRadius: 0,
    borderBottomRightRadius: 0,
    maxHeight: 400,
    ...Platform6.select({
      web: {
        alignSelf: "center",
        maxWidth: 500,
        minWidth: 300
      }
    })
  }
});

// src/components/modal/ModalContent.tsx
import React30 from "react";
import { StyleSheet as StyleSheet23 } from "react-native";
var ModalContent = (props) => {
  const { colors, isDark } = useBlossomTheme();
  const { title, description, children, actionButtons, containerStyle } = useMergedProps("ModalContent", props, {
    colors,
    isDark
  });
  return /* @__PURE__ */ React30.createElement(View_default, { style: [styles23.container, containerStyle] }, /* @__PURE__ */ React30.createElement(Text_default, { typography: "h5" }, title), description ? /* @__PURE__ */ React30.createElement(Text_default, { style: styles23.description }, description) : null, children, /* @__PURE__ */ React30.createElement(View_default, { row: true, style: styles23.buttonRow }, actionButtons?.map((buttonProps, index) => /* @__PURE__ */ React30.createElement(
    Button_default,
    {
      key: buttonProps.title,
      mode: index === 0 ? "plain" : "filled",
      style: styles23.button,
      ...buttonProps
    }
  ))));
};
var ModalContent_default = ModalContent;
var styles23 = StyleSheet23.create({
  container: {
    overflow: "scroll"
  },
  button: {
    marginHorizontal: 8
  },
  description: {
    marginVertical: 8
  },
  buttonRow: {
    justifyContent: "flex-end",
    backgroundColor: "transparent"
  }
});

// src/components/modal/Popover.tsx
import React31, {
  forwardRef as forwardRef8,
  useCallback as useCallback12,
  useEffect as useEffect13,
  useImperativeHandle as useImperativeHandle2,
  useRef as useRef5,
  useState as useState13
} from "react";
import {
  Modal as RNModal3,
  Pressable as Pressable6,
  StyleSheet as StyleSheet24,
  UIManager as UIManager2,
  findNodeHandle,
  Platform as Platform7
} from "react-native";
var OFFSET_PADDING = 16;
var TOP_DEFAULT_OFFSET = Platform7.OS === "android" ? 24 : 0;
var BOTTOM_DEFAULT_OFFSET = Platform7.OS === "android" ? -20 : 0;
var Popover = (props, ref) => {
  const { colors, isDark, options } = useBlossomTheme();
  const targetViewRef = useRef5(null);
  const {
    visible,
    position = "bottom",
    wrapContent,
    offset = 6,
    Target,
    targetRef,
    fitTargetWidth,
    onBackdropPress,
    children,
    contentStyle
  } = props;
  const { width: deviceWidth, isPortrait, isLandscape } = useDeviceInfo();
  const [showContent, setShowContent] = useState13(visible);
  const [positionStyle, setPositionStyle] = useState13({});
  useImperativeHandle2(
    ref,
    () => ({
      open: () => {
        setShowContent(true);
      },
      close: () => {
        setShowContent(false);
      }
    }),
    []
  );
  const measureContent = useCallback12(() => {
    const node = findNodeHandle(
      // Find the first children inside the target ref
      // eslint-disable-next-line
      // @ts-ignore
      // eslint-disable-next-line @typescript-eslint/no-unsafe-argument, @typescript-eslint/no-unsafe-member-access, no-underscore-dangle
      targetViewRef?.current?._children?.[0] || targetViewRef?.current || // eslint-disable-next-line
      // @ts-ignore
      targetRef?.current
    );
    if (!node) return;
    UIManager2.measure(
      node,
      (x, y, width, height, pageX, pageY) => {
        const offsetWidthMap = {
          top: deviceWidth,
          bottom: deviceWidth,
          left: pageX - offset,
          right: deviceWidth - (pageX + width + offset)
        };
        const positionStyleMap = {
          left: {
            right: deviceWidth - pageX + offset,
            top: pageY
          },
          right: {
            left: pageX + width + offset,
            top: pageY
          },
          top: {
            left: pageX,
            bottom: -pageY + offset + TOP_DEFAULT_OFFSET
          },
          bottom: {
            left: pageX,
            top: pageY + height + offset + BOTTOM_DEFAULT_OFFSET
          }
        };
        setPositionStyle({
          ...positionStyleMap[position],
          ...!fitTargetWidth && !wrapContent && (position === "top" || position === "bottom") && {
            left: OFFSET_PADDING,
            right: OFFSET_PADDING
          },
          maxWidth: offsetWidthMap[position],
          targetWidth: width
        });
      }
    );
  }, [deviceWidth, fitTargetWidth, offset, position, targetRef, wrapContent]);
  useEffect13(() => {
    setShowContent(visible);
  }, [visible]);
  useEffect13(() => {
    if (!showContent) return;
    measureContent();
  }, [measureContent, showContent, isPortrait, isLandscape]);
  return /* @__PURE__ */ React31.createElement(View_default, null, /* @__PURE__ */ React31.createElement(View_default, { ref: targetViewRef }, Target), /* @__PURE__ */ React31.createElement(
    RNModal3,
    {
      transparent: true,
      visible: showContent,
      onRequestClose: onBackdropPress,
      supportedOrientations: ["portrait", "landscape"]
    },
    /* @__PURE__ */ React31.createElement(
      Pressable6,
      {
        accessibilityRole: "alert",
        style: [styles24.backdrop],
        onPress: onBackdropPress
      },
      /* @__PURE__ */ React31.createElement(Pressable6, { accessibilityRole: "alert" }, /* @__PURE__ */ React31.createElement(
        View_default,
        {
          style: [
            styles24.content,
            styles24.shadow,
            positionStyle,
            {
              borderColor: colors.background300,
              shadowColor: colors.background200
            },
            fitTargetWidth && { width: positionStyle.targetWidth },
            contentStyle
          ]
        },
        positionStyle.maxWidth || positionStyle.targetWidth ? children : null
      ))
    )
  ));
};
var Popover_default = forwardRef8(Popover);
var styles24 = StyleSheet24.create({
  backdrop: {
    flex: 1
  },
  content: {
    position: "absolute",
    margin: 0,
    padding: 8,
    borderRadius: 8,
    borderWidth: 1,
    maxWidth: "100%"
  },
  shadow: {
    // android
    elevation: 5,
    // ios
    shadowOpacity: 0.5,
    shadowRadius: 10,
    shadowOffset: {
      width: 8,
      height: 8
    }
  }
});

// src/components/modal/Tooltip.tsx
import React32, { useEffect as useEffect14, useState as useState14 } from "react";
var Tooltip = (props) => {
  const { colors, isDark } = useBlossomTheme();
  const { visible, title, titleStyle, ...rest } = useMergedProps(
    "Tooltip",
    props,
    { colors, isDark }
  );
  const [showPopover, setShowPopover] = useState14(visible);
  useEffect14(() => {
    setShowPopover(visible);
  }, [visible]);
  return /* @__PURE__ */ React32.createElement(
    Popover_default,
    {
      visible: showPopover,
      contentStyle: {
        backgroundColor: colors.background900
      },
      wrapContent: true,
      onBackdropPress: () => setShowPopover(false),
      ...rest
    },
    /* @__PURE__ */ React32.createElement(Text_default, { style: [{ color: colors.text900 }, titleStyle] }, title)
  );
};
var Tooltip_default = Tooltip;

// src/components/modal/useCalculatedPosition.ts
import { useLayoutEffect, useMemo as useMemo11, useState as useState15 } from "react";
import { useWindowDimensions as useWindowDimensions3 } from "react-native";
var useCalculatedPosition = (popoverHeight, isVisible, targetRef) => {
  const { height: deviceHeight } = useWindowDimensions3();
  const [pressableLayout, setPressableLayout] = useState15({
    x: 0,
    y: 0,
    width: 0,
    height: 0
  });
  useLayoutEffect(() => {
    targetRef?.current?.measureInWindow((x, y, width, height) => {
      setPressableLayout({
        x,
        y,
        width,
        height
      });
    });
  }, [targetRef, isVisible]);
  const pickerPosition = useMemo11(() => {
    let autoPosition = "bottom";
    const remainingSpace = deviceHeight - pressableLayout.y - pressableLayout.height;
    if (remainingSpace < popoverHeight) {
      autoPosition = "top";
    }
    return autoPosition;
  }, [deviceHeight, popoverHeight, pressableLayout]);
  return {
    pickerPosition,
    setPressableLayout,
    offset: pickerPosition === "top" ? 0 : 0
  };
};

// src/components/select/Select.tsx
import React34, { useCallback as useCallback13, useEffect as useEffect15, useRef as useRef6, useState as useState16 } from "react";
import {
  Pressable as Pressable8,
  StyleSheet as StyleSheet26,
  FlatList,
  Platform as Platform8
} from "react-native";

// src/components/select/SelectItem.tsx
import React33, { memo } from "react";
import { Pressable as Pressable7, StyleSheet as StyleSheet25 } from "react-native";
var SelectItem = (props) => {
  const { colors } = useBlossomTheme();
  const {
    item,
    onPress,
    withTickIcon = true,
    leftIcon,
    isSelected,
    style,
    size
  } = props;
  return /* @__PURE__ */ React33.createElement(
    Pressable7,
    {
      accessibilityRole: "button",
      style: [
        styles25.item,
        isSelected && {
          backgroundColor: colors.primaryTransparent100
        },
        style
      ],
      onPress: item.disabled ? void 0 : onPress
    },
    leftIcon || withTickIcon && isSelected && /* @__PURE__ */ React33.createElement(
      Icon_default,
      {
        family: "MaterialCommunityIcons",
        name: "check",
        size: 20,
        style: styles25.icon
      }
    ),
    /* @__PURE__ */ React33.createElement(
      SizedText_default,
      {
        mode: "body",
        size,
        style: [
          item.disabled && {
            color: colors.text500
          }
        ]
      },
      item.label
    )
  );
};
var SelectItem_default = memo(SelectItem);
var styles25 = StyleSheet25.create({
  item: {
    padding: 8,
    marginHorizontal: 4,
    flexDirection: "row",
    alignItems: "center"
  },
  label: {
    paddingStart: 12,
    alignItems: "center",
    justifyContent: "center",
    alignSelf: "center"
  },
  icon: {
    marginEnd: 6
  }
});

// src/components/select/Select.tsx
var PICKER_HEIGHT = 180;
var Select = (props) => {
  const { colors, isDark, options: themeOptions } = useBlossomTheme();
  const {
    options = [],
    value,
    displayValue,
    onValueChange,
    onClearPress,
    searchable,
    clearable,
    defaultValue: defaultValue2,
    isLoading,
    disabled,
    label,
    placeholder = "Select Option",
    pickerHeight = PICKER_HEIGHT,
    pickerProps,
    status,
    size,
    renderItem,
    inputProps
  } = useMergedProps("Select", props, { colors, isDark });
  const anchorRef = useRef6(null);
  const flatListRef = useRef6(null);
  const [showPicker, setShowPicker] = useState16(false);
  const [showBottomSheet, setShowBottomSheet] = useState16(false);
  const [selectedValue, setSelectedValue] = useState16(value);
  const { offset, pickerPosition } = useCalculatedPosition(
    pickerHeight,
    showPicker,
    anchorRef
  );
  useEffect15(() => {
    setSelectedValue(value);
  }, [value]);
  useEffect15(() => {
    setSelectedValue(defaultValue2);
  }, []);
  const getSelectedIndex = useCallback13(() => {
    return options.findIndex(
      (item) => JSON.stringify(item.value) === JSON.stringify(selectedValue)
    );
  }, [options, selectedValue]);
  const getDisplayValue = useCallback13(() => {
    return displayValue || options[getSelectedIndex()]?.label || "";
  }, [displayValue, options, getSelectedIndex]);
  const openPicker = useCallback13(() => {
    if (disabled) return;
    if (Platform8.OS === "android") {
      setShowBottomSheet(true);
    } else {
      setShowPicker(true);
    }
  }, [disabled]);
  const closePicker = useCallback13(() => {
    setShowPicker(false);
    setShowBottomSheet(false);
  }, []);
  const RightView = useCallback13(
    () => /* @__PURE__ */ React34.createElement(
      View_default,
      {
        row: true,
        style: [
          disabled && {
            backgroundColor: colors.background200
          }
        ]
      },
      isLoading && /* @__PURE__ */ React34.createElement(ActivityIndicator_default, { size: "small", style: styles26.loader }),
      clearable && getDisplayValue() && /* @__PURE__ */ React34.createElement(
        Icon_default,
        {
          family: "Ionicons",
          name: "close",
          size: 24,
          style: styles26.closeIcon,
          color: colors.background700,
          onPress: () => {
            onClearPress?.();
            onValueChange?.(void 0);
          }
        }
      ),
      /* @__PURE__ */ React34.createElement(
        Icon_default,
        {
          family: "Ionicons",
          name: "chevron-down",
          size: 24,
          color: disabled ? colors.text500 : colors.text100
        }
      )
    ),
    [
      disabled,
      colors.background200,
      colors.background700,
      colors.text500,
      colors.text100,
      isLoading,
      clearable,
      getDisplayValue,
      onClearPress,
      onValueChange
    ]
  );
  return /* @__PURE__ */ React34.createElement(
    Popover_default,
    {
      targetRef: anchorRef,
      visible: showPicker,
      position: pickerPosition,
      offset,
      fitTargetWidth: true,
      contentStyle: [
        styles26.popover,
        {
          maxHeight: pickerHeight,
          backgroundColor: colors.background100,
          borderRadius: themeOptions?.borderRadius,
          borderColor: colors.background500
        }
      ],
      onBackdropPress: closePicker,
      Target: /* @__PURE__ */ React34.createElement(
        Pressable8,
        {
          ref: anchorRef,
          accessibilityRole: "button",
          onPress: openPicker
        },
        /* @__PURE__ */ React34.createElement(
          SearchInput_default,
          {
            accessibilityLabel: "Select input field",
            left: null,
            right: /* @__PURE__ */ React34.createElement(RightView, null),
            inputStyle: [
              disabled && {
                backgroundColor: colors.background200
              }
            ],
            textStyle: [
              !disabled && {
                color: colors.text100
              }
            ],
            label,
            placeholder,
            value: getDisplayValue(),
            disabled: disabled || !searchable,
            shouldMockDisableState: true,
            onPressOut: openPicker,
            status,
            size,
            ...inputProps
          }
        ),
        /* @__PURE__ */ React34.createElement(BottomSheet_default, { visible: showBottomSheet, onBackdropPress: closePicker }, placeholder ? /* @__PURE__ */ React34.createElement(Text_default, { typography: "h6" }, placeholder) : null, /* @__PURE__ */ React34.createElement(Spacer_default, { height: 4 }), /* @__PURE__ */ React34.createElement(
          FlatList,
          {
            ref: flatListRef,
            data: options,
            keyExtractor: (item) => item.label,
            ...pickerProps,
            renderItem: renderItem || (({ item, index }) => /* @__PURE__ */ React34.createElement(
              SelectItem_default,
              {
                size,
                item,
                isSelected: index === getSelectedIndex(),
                onPress: () => {
                  setSelectedValue(item.value);
                  onValueChange?.(item.value, item, index);
                  closePicker();
                }
              }
            ))
          }
        ))
      )
    },
    /* @__PURE__ */ React34.createElement(
      FlatList,
      {
        ref: flatListRef,
        data: options,
        keyExtractor: (item) => item.label,
        ...pickerProps,
        renderItem: renderItem || (({ item, index }) => /* @__PURE__ */ React34.createElement(
          SelectItem_default,
          {
            size,
            item,
            isSelected: index === getSelectedIndex(),
            onPress: () => {
              setSelectedValue(item.value);
              onValueChange?.(item.value, item, index);
              closePicker();
            }
          }
        ))
      }
    )
  );
};
var Select_default = Select;
var styles26 = StyleSheet26.create({
  closeIcon: {
    paddingHorizontal: 4
  },
  loader: {
    paddingHorizontal: 4
  },
  popover: {
    borderWidth: 1,
    padding: 0
  }
});

// src/components/select/MultiSelect.tsx
import React35, { useCallback as useCallback14, useEffect as useEffect16, useState as useState17 } from "react";
var MultiSelect = (props) => {
  const { colors, isDark } = useBlossomTheme();
  const {
    values = [],
    onValuesChange,
    disabled,
    maxSelectCount,
    label,
    placeholder,
    defaultValue: defaultValue2,
    ...rest
  } = useMergedProps("MultiSelect", props, { colors, isDark });
  const [selectedItems, setSelectedItems] = useState17([]);
  const [selectedValues, setSelectedValues] = useState17(values);
  useEffect16(() => {
    if (!defaultValue2) return;
    setSelectedValues(defaultValue2);
    const defaultItems = defaultValue2.map(
      (item) => rest.options?.find(
        (optionItem) => JSON.stringify(optionItem.value) === JSON.stringify(item)
      )
    );
    setSelectedItems(defaultItems);
  }, []);
  const getDisplayValue = useCallback14(() => {
    return selectedItems.map((item) => item.label).join(", ");
  }, [selectedItems]);
  const handleValueChange = useCallback14(
    (selectedItem) => {
      if (!selectedItem) {
        setSelectedItems([]);
        setSelectedValues([]);
        return;
      }
      let nextItems = [...selectedItems];
      let nextValues = [...selectedValues];
      const indexFoundValue = selectedItems.findIndex(
        (item) => JSON.stringify(item) === JSON.stringify(selectedItem)
      );
      if (indexFoundValue === -1) {
        if (maxSelectCount && nextValues.length >= maxSelectCount) {
          return;
        }
        nextItems.push(selectedItem);
        nextValues.push(selectedItem.value);
      } else {
        nextItems = selectedItems.filter(
          (item) => JSON.stringify(item) !== JSON.stringify(selectedItem)
        );
        nextValues = selectedValues.filter(
          (item) => JSON.stringify(item) !== JSON.stringify(selectedItem)
        );
      }
      onValuesChange?.(nextValues, selectedItems);
      setSelectedItems(nextItems);
      setSelectedValues(nextValues);
    },
    [selectedItems, selectedValues, maxSelectCount, onValuesChange]
  );
  const isItemSelected = useCallback14(
    (targetItem) => {
      return !!selectedItems?.find(
        (item) => JSON.stringify(item) === JSON.stringify(targetItem)
      );
    },
    [selectedItems]
  );
  return /* @__PURE__ */ React35.createElement(
    Select_default,
    {
      label,
      placeholder,
      displayValue: getDisplayValue(),
      renderItem: ({ item }) => /* @__PURE__ */ React35.createElement(
        SelectItem_default,
        {
          size: rest?.size,
          item,
          leftIcon: /* @__PURE__ */ React35.createElement(
            Checkbox_default,
            {
              value: isItemSelected(item),
              onValueChange: () => handleValueChange(item),
              disabled: item.disabled,
              size: "small"
            }
          ),
          isSelected: isItemSelected(item),
          onPress: () => handleValueChange(item)
        }
      ),
      ...rest,
      disabled,
      onValueChange: void 0,
      onClearPress: () => {
        rest?.onClearPress?.();
        handleValueChange(void 0);
      },
      value: void 0
    }
  );
};
var MultiSelect_default = MultiSelect;

// src/components/progressBar/ProgressBar.tsx
import React36, { useEffect as useEffect17, useMemo as useMemo12, useRef as useRef7, useState as useState18 } from "react";
import { Animated as Animated5, Easing as Easing3, StyleSheet as StyleSheet27 } from "react-native";
var ProgressBar = (props) => {
  const { colors, isDark } = useBlossomTheme();
  const {
    value = 0,
    color = colors.background200,
    trackColor,
    width,
    height,
    indeterminate,
    reverseDirection,
    style,
    status = "primary",
    size = "medium"
  } = useMergedProps("ProgressBar", props, { colors, isDark });
  const progressValue = useRef7(new Animated5.Value(0)).current;
  const [progressBarWidth, setProgressBarWidth] = useState18(0);
  const animationLoop = useMemo12(
    () => Animated5.loop(
      Animated5.sequence([
        Animated5.timing(progressValue, {
          toValue: 1,
          duration: 1e3,
          easing: Easing3.linear,
          useNativeDriver: true
        })
      ])
    ),
    [progressValue]
  );
  useEffect17(() => {
    if (indeterminate) {
      animationLoop.start();
    } else {
      animationLoop.reset();
    }
  }, [animationLoop, indeterminate]);
  return /* @__PURE__ */ React36.createElement(
    View_default,
    {
      style: [
        styles27.container,
        {
          backgroundColor: color,
          width,
          height: height || sizeMap10[size],
          borderRadius: height || sizeMap10[size]
        },
        reverseDirection && styles27.reverse,
        style
      ],
      onLayout: (e) => {
        setProgressBarWidth(e.nativeEvent.layout.width);
      }
    },
    /* @__PURE__ */ React36.createElement(
      Animated5.View,
      {
        style: [
          styles27.container,
          {
            backgroundColor: trackColor || colors[getStatusColorName(status, isDark)],
            width: indeterminate ? "40%" : `${value === 0 ? 0 : value}%`,
            height: height || sizeMap10[size],
            borderRadius: height || sizeMap10[size]
          },
          {
            transform: indeterminate ? [
              {
                translateX: progressValue.interpolate({
                  inputRange: [0, 1],
                  outputRange: reverseDirection ? [progressBarWidth, -progressBarWidth * 0.9] : [-progressBarWidth * 0.5, progressBarWidth]
                })
              },
              {
                scaleX: progressValue.interpolate({
                  inputRange: [0, 0.4, 0.75, 0.9, 1],
                  outputRange: [0.4, 1, 0.4, 0.2, 0.1]
                })
              }
            ] : []
          }
        ]
      }
    )
  );
};
var ProgressBar_default = ProgressBar;
var styles27 = StyleSheet27.create({
  container: {
    // NOTE: this height is kind of weird to be here to make the track color view to work!!
    height: 12,
    borderRadius: 12,
    overflow: "hidden"
  },
  reverse: {
    flexDirection: "row-reverse"
  }
});
var sizeMap10 = {
  small: 8,
  medium: 10,
  large: 12
};
export {
  Accordion_default as Accordion,
  ActivityIndicator_default as ActivityIndicator,
  Avatar_default as Avatar,
  BlossomThemeProvider,
  BottomSheet_default as BottomSheet,
  Button_default as Button,
  Card_default as Card,
  Checkbox_default as Checkbox,
  Chip_default as Chip,
  ComponentManager,
  Divider_default as Divider,
  ExpandableText_default as ExpandableText,
  FAB_default as FAB,
  Icon_default as Icon,
  Link_default as Link,
  Modal_default as Modal,
  ModalContent_default as ModalContent,
  MultiSelect_default as MultiSelect,
  OtpInput_default as OtpInput,
  Popover_default as Popover,
  ProgressBar_default as ProgressBar,
  Radio_default as Radio,
  SearchInput_default as SearchInput,
  SegmentedButton_default as SegmentedButton,
  Select_default as Select,
  SelectItem_default as SelectItem,
  ShimmerView_default as ShimmerView,
  Spacer_default as Spacer,
  Switch_default as Switch,
  Text_default as Text,
  TextInput_default as TextInput,
  Tooltip_default as Tooltip,
  View_default as View,
  safeDeepMerge,
  useBlossomTheme,
  useCalculatedPosition,
  useDeviceInfo,
  useMergedProps
};
